<?php

// Element Description: PT Banner

class PT_Banner extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_banner_mapping' ) );
        add_shortcode( 'pt_banner', array( $this, 'pt_banner_html' ) );
        add_shortcode( 'pt_banner_item', array( $this, 'pt_banner_item_html' ) );
    }
     
    // Element Mapping
    public function pt_banner_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Banner", "imate"),
            "base" => "pt_banner",
            "as_parent" => array('only' => 'pt_banner_item'),
            "content_element" => true,
            "show_settings_on_create" => true,
            "is_container" => true,
            "icon" => "shortcode-icon-banner",
            "category" => esc_html__("By PT", "imate"),
            "params" => array(
                array(
                    "type"        => "el_id",
                    "heading"     => esc_html__( "Uniq ID", "imate" ),
                    "param_name"  => "uniq_id",
                    "value"       => uniqid(),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Banner Style", "imate" ),
                    "param_name"  => "style",
                    "value"       => array(
                        esc_html__( "Style 1", "imate" ) => "style1",
                        esc_html__( "Style 2", "imate" ) => "style2",
                    ),
                    "std"         => "style1",
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Infinite loop", "imate" ),
                    "param_name"  => "infinite_loop",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "label" => esc_html__( "Restart the slider automatically as it passes the last slide.", "imate" ),
                            "on"    => esc_html__("On", "imate"),
                            "off"   => esc_html__("Off", "imate"),
                        ),
                    ),
                    "default_set" => true,
                ),
                array(
                    "type"        => "number",
                    "heading"     => esc_html__( "Transition speed", "imate" ),
                    "param_name"  => "speed",
                    "value"       => "300",
                    "min"         => "100",
                    "max"         => "10000",
                    "step"        => "100",
                    "suffix"      => "ms",
                    "description" => esc_html__( "Speed at which next slide comes.", "imate" ),
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Autoplay Slides", "imate" ),
                    "param_name"  => "autoplay",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "label" => esc_html__( "Enable Autoplay", "imate" ),
                            "on"    => esc_html__("On", "imate"),
                            "off"   => esc_html__("Off", "imate"),
                        ),
                    ),
                    "default_set" => true,
                ),
                array(
                    "type"       => "number",
                    "heading"    => esc_html__( "Autoplay Speed", "imate" ),
                    "param_name" => "autoplay_speed",
                    "value"      => "5000",
                    "min"        => "100",
                    "max"        => "10000",
                    "step"       => "10",
                    "suffix"     => "ms",
                    "dependency" => Array( "element" => "autoplay", "value" => array( "on" ) ),
                ),
                array(
                    "type"       => "switch",
                    "heading"    => esc_html__( "Adaptive Height", "imate" ),
                    "param_name" => "adaptive_height",
                    "value"      => "on",
                    "options"    => array(
                        "on" => array(
                            "label" => esc_html__( "Turn on Adaptive Height", "imate" ),
                            "on"    => esc_html__("On", "imate"),
                            "off"   => esc_html__("Off", "imate"),
                        ),
                    ),
                    "default_set" => true,
                ),
                array(
                    "type"       => "number",
                    "heading"    => esc_html__( "Height", "imate" ),
                    "param_name" => "height",
                    "min"        => "540",
                    "max"        => "1500",
                    "step"       => "10",
                    "suffix"     => "px",
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Content container type", "imate" ),
                    "param_name"  => "container",
                    "value"       => array(
                        esc_html__( "Container", "imate" ) => "container",
                        esc_html__( "Container fluid", "imate" ) => "container-fluid",
                    ),
                    "std"         => "container",
                ),
                array(
                    "type"       => "switch",
                    "heading"    => esc_html__( "Social buttons", "imate" ),
                    "param_name" => "social_buttons",
                    "value"      => "on",
                    "options"    => array(
                        "on" => array(
                            "on"    => esc_html__("On", "imate"),
                            "off"   => esc_html__("Off", "imate"),
                        ),
                    ),
                    "default_set" => true,
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Social buttons align", "imate" ),
                    "param_name"  => "social_buttons_align",
                    "value"       => array(
                        esc_html__( "left", "imate" ) => "left",
                        esc_html__( "right", "imate" ) => "right",
                    ),
                    "dependency" => Array( "element" => "social_buttons", "value" => array( "on" ) ),
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Social buttons color", "imate"),
                    "param_name" => "social_buttons_color",
                    "dependency" => Array( "element" => "social_buttons", "value" => array( "on" ) ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Wave Type", "imate" ),
                    "param_name"  => "wave_type",
                    "value"       => array(
                        esc_html__( "Disable", "imate" ) => "disable",
                        esc_html__( "Style 1", "imate" ) => "style1",
                        esc_html__( "Style 2", "imate" ) => "style2",
                        esc_html__( "Style 3", "imate" ) => "style4",
                        esc_html__( "Style 4", "imate" ) => "style5",
                        esc_html__( "Style 5", "imate" ) => "style6",
                    ),
                    "std"         => "style1",
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Pagination dots", "imate" ),
                    "param_name"  => "navigation",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__("On", "imate"),
                            "off"   => esc_html__("Off", "imate"),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__("Navigation", "imate"),
                ),
                array(
                    "type"        => "colorpicker",
                    "heading"     => esc_html__( "Pagination dots color", "imate" ),
                    "param_name"  => "navigation_color",
                    "dependency" => Array( "element" => "navigation", "value" => array( "on" ) ),
                    "group"       => esc_html__("Navigation", "imate"),
                ),
                array(
                    "type"        => "colorpicker",
                    "heading"     => esc_html__( "Pagination active dot color", "imate" ),
                    "param_name"  => "navigation_color_a",
                    "dependency" => Array( "element" => "navigation", "value" => array( "on" ) ),
                    "group"       => esc_html__("Navigation", "imate"),
                ),
            ),
            "js_view" => 'VcColumnView'
        ) );
        vc_map( array(
            "name" => esc_html__("Banner item", "imate"),
            "base" => "pt_banner_item",
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-banner",
            "as_child" => array('only' => 'pt_banner'),
            "params" => array(
                array(
                    "type"        => "el_id",
                    "heading"     => esc_html__( "Uniq ID", "imate" ),
                    "param_name"  => "uniq_id",
                    "value"       => uniqid(),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Type", "imate" ),
                    "param_name"  => "slide_type",
                    "value"      => array(
                        esc_html__( "Default", "imate" ) => "default",
                        esc_html__( "Event", "imate" ) => "event",
                    ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Background type", "imate" ),
                    "param_name"  => "background_type",
                    "value"      => array(
                        esc_html__( "Image", "imate" ) => "image",
                        esc_html__( "Gradient", "imate" ) => "gradient",
                        esc_html__( "Dots", "imate" ) => "dots",
                        esc_html__( "Color", "imate" ) => "color",
                    ),
                ),
                array(
                    "type" => "attach_image",
                    "heading" => esc_html__("Background image", "imate"),
                    "param_name" => "background_image",
                    "dependency" => Array("element" => "background_type", "value" => "image" ),
                ),
                array(
                    "type" => "gradient",
                    "base_gradient" => "#feb332 0%,#d38d14 100%",
                    "base_orientation" => "vertical",
                    "heading" => esc_html__("Background gradient", "imate"),
                    "param_name" => "background_gradient",
                    "dependency" => Array("element" => "background_type", "value" => "gradient" ),
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Background color", "imate"),
                    "param_name" => "background_color",
                    "dependency" => Array("element" => "background_type", "value" => array('color', 'dots') ),
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Background Video url", "imate"),
                    "param_name" => "video_url",
                    "description" => esc_html__("Source YouTube, Vimeo and mp4 file", "imate"),
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Event date", "imate"),
                    "param_name" => "event_date",
                    "dependency" => Array("element" => "slide_type", "value" => array('event') ),
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Event Address", "imate"),
                    "param_name" => "event_address",
                    "dependency" => Array("element" => "slide_type", "value" => array('event') ),
                ),
                array(
                    "type" => "textarea",
                    "heading" => esc_html__("Sub Heading", "imate"),
                    "param_name" => "sub_heading",
                    "admin_label" => true,
                ),
                array(
                    "type" => "textarea",
                    "heading" => esc_html__("Heading", "imate"),
                    "param_name" => "heading",
                    "admin_label" => true,
                    "description" => __("Wrap the text in { } if you want the text to be another color.<br>Example: Minds your work {level}", "imate"),
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Heading uppercase", "imate" ),
                    "param_name"  => "heading_uppercase",
                    "value"       => "off",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__("On", "imate"),
                            "off"   => esc_html__("Off", "imate"),
                        ),
                    ),
                    "default_set" => false,
                ),
                array(
                    "type" => "textarea_html",
                    "holder" => "div",
                    "heading" => esc_html__("Text", "imate"),
                    "admin_label" => false,
                    "param_name" => "content",
                ),
                array(
                    "type" => "vc_link",
                    "heading" => esc_html__("Link", "imate"),
                    "param_name" => "link",
                ),
                array(
                    "type" => "vc_link",
                    "heading" => esc_html__("Link 2", "imate"),
                    "param_name" => "link2",
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Side Content", "imate" ),
                    "param_name"  => "side_content",
                    "value"      => array(
                        esc_html__( "None", "imate" ) => "none",
                        esc_html__( "Image on Laptop", "imate" ) => "laptop_image",
                        esc_html__( "Contact form", "imate" ) => "contact_form",
                    ),
                ),
                array(
                    "type" => "attach_image",
                    "heading" => esc_html__("Image on Laptop", "imate"),
                    "param_name" => "laptop_image",
                    "dependency" => Array("element" => "side_content", "value" => "laptop_image" ),
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Contact Form", "imate"),
                    "param_name" => "contact_form",
                    "dependency" => Array("element" => "side_content", "value" => "contact_form" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Color overlay", "imate" ),
                    "param_name"  => "color_overlay",
                    "value"      => array(
                        esc_html__( "None", "imate" ) => "none",
                        esc_html__( "Gradient", "imate" ) => "gradient",
                        esc_html__( "Color", "imate" ) => "color",
                    ),
                    "group"       => esc_html__("Design", "imate"),
                ),
                array(
                    "type" => "gradient",
                    "base_gradient" => "#112f76 0%,#003ae1 100%",
                    "base_orientation" => "vertical",
                    "heading" => esc_html__("Color overlay gradient", "imate"),
                    "param_name" => "color_overlay_gradient",
                    "dependency" => Array("element" => "color_overlay", "value" => "gradient" ),
                    "group"      => esc_html__("Design", "imate"),
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Color overlay color", "imate"),
                    "param_name" => "color_overlay_color",
                    "dependency" => Array("element" => "color_overlay", "value" => "color" ),
                    "group"      => esc_html__("Design", "imate"),
                ),
                array(
                    "type"        => "textfield",
                    "heading"     => esc_html__( "Overlay opacity", "imate" ),
                    "param_name"  => "opacity_overlay",
                    "value"       => "0.3",
                    "description" => esc_html__("Min 0, Max 1. Example: 0.45", "imate"),
                    "dependency" => Array("element" => "color_overlay", "value" => array('gradient', 'color') ),
                    "group"       => esc_html__("Design", "imate"),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Item color", "imate" ),
                    "param_name"  => "text_color",
                    "value"      => array(
                        esc_html__( "Black", "imate" ) => "black",
                        esc_html__( "White", "imate" ) => "white",
                        esc_html__( "Custom", "imate" ) => "custom",
                    ),
                    "group"       => esc_html__("Design", "imate"),
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Select Item color", "imate"),
                    "param_name" => "text_color_hex",
                    "dependency" => Array("element" => "text_color", "value" => "custom" ),
                    "group"      => esc_html__("Design", "imate"),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Text align", "imate" ),
                    "param_name"  => "text_align",
                    "value"      => array(
                        esc_html__( "Left", "imate" ) => "tal",
                        esc_html__( "Center", "imate" ) => "tac",
                        esc_html__( "Right", "imate" ) => "tar",
                    ),
                    "std" => "tal",
                    "group"       => esc_html__("Design", "imate"),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Vertical align", "imate" ),
                    "param_name"  => "vertical_align",
                    "value"      => array(
                        esc_html__( "Top", "imate" ) => "top",
                        esc_html__( "Middle", "imate" ) => "middle",
                        esc_html__( "Bottom", "imate" ) => "bottom",
                    ),
                    "std" => "middle",
                    "group"       => esc_html__("Design", "imate"),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Background image position", "imate" ),
                    "param_name"  => "bg_position",
                    "value"      => array(
                        esc_html__( "Top Left", "imate" ) => "top left",
                        esc_html__( "Top Center", "imate" ) => "top center",
                        esc_html__( "Top Right", "imate" ) => "top right",
                        esc_html__( "Middle Left", "imate" ) => "center left",
                        esc_html__( "Middle Center", "imate" ) => "center center",
                        esc_html__( "Middle Right", "imate" ) => "center right",
                        esc_html__( "Bottom Left", "imate" ) => "bottom left",
                        esc_html__( "Bottom Center", "imate" ) => "bottom center",
                        esc_html__( "Bottom Right", "imate" ) => "bottom right",
                    ),
                    "std" => "center center",
                    "group"       => esc_html__("Design", "imate"),
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Heading font size", "imate"),
                    "param_name" => "heading_size",
                    "group"      => esc_html__("Design", "imate"),
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Sub Heading font size", "imate"),
                    "param_name" => "sub_heading_size",
                    "group"      => esc_html__("Design", "imate"),
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Text font size", "imate"),
                    "param_name" => "text_size",
                    "group"      => esc_html__("Design", "imate"),
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Event detail color", "imate"),
                    "param_name" => "event_color",
                    "dependency" => Array("element" => "slide_type", "value" => "event" ),
                    "group"      => esc_html__( "Design", "imate" ),
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Sub Heading color", "imate"),
                    "param_name" => "sub_heading_color",
                    "group"      => esc_html__( "Design", "imate" ),
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Heading color", "imate"),
                    "param_name" => "heading_color",
                    "group"      => esc_html__( "Design", "imate" ),
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Heading decor color", "imate"),
                    "param_name" => "heading_decor_color",
                    "group"      => esc_html__( "Design", "imate" ),
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Button color", "imate"),
                    "param_name" => "button_color",
                    "dependency" => Array("element" => "link_button", "value" => "on" ),
                    "group"      => esc_html__( "Design", "imate" ),
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Button 2 color", "imate"),
                    "param_name" => "button_color2",
                    "dependency" => Array("element" => "link_button", "value" => "on" ),
                    "group"      => esc_html__( "Design", "imate" ),
                ),
            )
        ) );
    }
     
     
    // Element HTML
    public function pt_banner_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                    'style' => 'style1',
                    'infinite_loop' => 'on',
                    'speed' => '300',
                    'autoplay' => 'on',
                    'autoplay_speed' => '5000',
                    'adaptive_height' => 'on',
                    'height' => '',
                    'wave_type' => 'style1',
                    'container' => 'container',
                    'navigation' => 'on',
                    'navigation_color' => '',
                    'navigation_color_a' => '',
                    'pauseohover' => 'on',
                    'social_buttons' => 'on',
                    'social_buttons_align' => 'left',
                    'social_buttons_color' => '',
                ), 
                $atts
            )
        );


        $banner_area_class = $id = 'banner-'.$uniq_id;
        $banner_class = $banner_style = $pagination_buttons = '';

        if(!empty($height)) {
            $banner_style .= 'height: '.$height.'px;';
            $banner_class .= ' fixed-height';
        }

        $banner_class .= ' '.$style;

        if($infinite_loop == 'on') {
            $infinite_loop = 'true';
        } else {
            $infinite_loop = 'false';
        }

        if($autoplay == 'on') {
            $autoplay = 'true';
        } else {
            $autoplay = 'false';
        }

        if($pauseohover == 'on') {
            $pauseohover = 'true';
        } else {
            $pauseohover = 'false';
        }

        if($navigation == 'on') {
            $navigation = 'true';
        } else {
            $navigation = 'false';
        }

        $banner_area_class .= ' autoplay-'.$autoplay;

        if($social_buttons == 'on') {
            $banner_area_class .= ' social-buttons-align-'.$social_buttons_align;
        }

        if($wave_type != 'disable') {
            $banner_area_class .= ' with-wave';
        }

        wp_enqueue_style( 'owl-carousel-css', get_template_directory_uri() . '/css/owl.carousel.css');
        wp_enqueue_script( 'owl-carousel-js', get_template_directory_uri() . '/js/owl.carousel.min.js', array('jquery'), true );
        wp_enqueue_script( 'imate-script', get_template_directory_uri() . '/js/script.js' );

        wp_add_inline_script('imate-script', "jQuery(document).ready(function(jQuery) {
            jQuery('.".esc_attr($id)." .banner').each(function(){
                var head_slider = jQuery(this),
                    head_slider_area = head_slider.parent();

                head_slider.on('initialized.owl.carousel',function(property){
                    var current = property.item.index;
                    if(jQuery(property.target).find('.owl-item').eq(current).find('video').length > 0) {
                        jQuery(property.target).find('.owl-item').eq(current).find('video').get(0).play();
                    }
                });

                if(jQuery(this).find('.item').length > 1){

                    if(".$navigation." == true) {
                        var dots = head_slider_area.find('.dots'),
                            style = '';
                        if(".$autoplay." == true) {
                            style = 'transition: stroke-dashoffset ".$autoplay_speed."ms ease';
                        }
                        head_slider.find('.item').each(function(index) {
                            jQuery(this).attr('data-index', index);
                            dots.append('<div class=\"dot-item\"><svg class=\"progress-ring\" width=\"20\" height=\"20\"><circle class=\"progress-ring__circle\" stroke=\"white\" stroke-width=\"2\" fill=\"transparent\" r=\"9\" cx=\"10\" cy=\"10\" style=\"'+style+'\"/></svg></div>');
                        });

                        head_slider_area.on('click', '.dots .dot-item:not(.current)', function() {
                            var index = jQuery(this).index();
                            head_slider.trigger('to.owl.carousel', [index]);
                        });
                    }
 
                    head_slider.on('initialized.owl.carousel translated.owl.carousel', function(event) {
                        var current = event.item.index,
                            index = jQuery(event.target).find('.owl-item').eq(current).find('.item').attr('data-index'),
                            count = event.item.count;

                        if(index < 0) {
                            index = 0;
                        }

                        if(head_slider_area.find('.dots').length > 0) {
                            dots.find('.dot-item').eq(index).addClass('current').find('circle').css('transition', 'stroke-dashoffset ".$autoplay_speed."ms ease').parents('.dot-item').siblings().removeClass('current').find('circle').css('transition', 'stroke-dashoffset 800ms ease');
                        }

                        if(head_slider.find('.owl-item.active .item').hasClass('white')) {
                            head_slider_area.addClass('current-white').removeClass('current-black');
                        }
                        if(head_slider.find('.owl-item.active .item').hasClass('black')) {
                            head_slider_area.addClass('current-black').removeClass('current-white');
                        }
                    });

                    head_slider.addClass('owl-carousel').owlCarousel({
                        loop: ".esc_js($infinite_loop).",
                        items:1,
                        nav: false,
                        dots: false,
                        autoplay: ".esc_js($autoplay).",
                        autoplayTimeout: ".esc_js($autoplay_speed).",
                        autoplayHoverPause: false,
                        navText: false,
                        smartSpeed: ".esc_js($speed).",
                    });
                } else {
                    if(head_slider.find('.item').hasClass('white')) {
                        head_slider_area.addClass('current-white').removeClass('current-black');
                    }
                    if(head_slider.find('.item').hasClass('black')) {
                        head_slider_area.addClass('current-black').removeClass('current-white');
                    }
                }
            });
        });");

        $custom_css = "";

        if(isset($social_buttons_color) && !empty($social_buttons_color)) {
            $custom_css .= '.'.$id.' .social-buttons-text {
                color: '.$social_buttons_color.';
            }';
        }

        if(isset($navigation_color) && !empty($navigation_color)) {
            $custom_css .= '.'.$id.'.banner-area .banner-bottom .dots .dot-item:before {
                background-color: '.$navigation_color.';
            }';
            $custom_css .= '.'.$id.'.banner-area .banner-bottom .dots .dot-item svg circle {
                stroke: '.$navigation_color.';
            }';
        }

        if(isset($navigation_color_a) && !empty($navigation_color_a)) {
            $custom_css .= '.'.$id.'.banner-area .banner-bottom .dots .dot-item.current:before {
                background-color: '.$navigation_color_a.';
            }';
        }

        if(!empty($custom_css)) {
            wp_enqueue_style('imate-custom-style', get_template_directory_uri() . '/css/custom_script.css');
            wp_add_inline_style( 'imate-custom-style', $custom_css );
        }
 
        if(!empty($content)) {
            $content = str_replace('[pt_banner_item', '[pt_banner_item style="'.$style.'" container="'.$container.'" social_buttons="'.$social_buttons.'"', $content);
        }

        $html = '<div class="banner-area '.esc_attr($banner_area_class).'">';
            if($social_buttons == 'on' && !empty(imate_styles()['social_buttons_content']) && $style == 'style1') {
                $html .= '<div class="banner-social-buttons"><div><i class="base-icons-share"></i>'.wp_kses_post(imate_styles()['social_buttons_content']).'</div></div>';
            }
            if($navigation == 'true') {
                $html .= '<div class="banner-bottom">';
                    $html .= '<div class="'.esc_html($container).'">';
                        $html .= '<div class="dots"></div>';
                    $html .= '</div>';
                $html .= '</div>';
            }
            $html .= '<div class="banner '.esc_attr($banner_class).'" style="'.esc_attr($banner_style).'">';
                $html .= do_shortcode($content);
            $html .= '</div>';
            if($wave_type != 'disable') {
                $html .= '<div class="wave-block wave-'.esc_attr($wave_type).'"></div>';
            }
        $html .= '</div>';

        return $html;
         
    }

    // Element HTML
    public function pt_banner_item_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                    'slide_type' => 'default',
                    'background_type' => 'image',
                    'background_image' => '',
                    'background_gradient' => '',
                    'background_color' => '',
                    'video_url' => '',
                    'event_date' => '',
                    'event_address' => '',
                    'sub_heading' => '',
                    'heading' => '',
                    'heading_uppercase' => 'off',
                    'heading_decor_line' => 'off',
                    'text' => '',
                    'link' => '',
                    'link2' => '',
                    'side_content' => 'none',
                    'laptop_image' => '',
                    'contact_form' => '',
                    'color_overlay' => 'none',
                    'color_overlay_gradient' => '',
                    'color_overlay_color' => '',
                    'opacity_overlay' => '0.3',
                    'text_align' => 'tal',
                    'vertical_align' => 'middle',
                    'bg_position' => 'center center',
                    'text_color' => 'black',
                    'text_color_hex' => '',
                    'custom_text_color_hex' => '',
                    'event_color' => '',
                    'sub_heading_color' => '',
                    'heading_color' => '',
                    'heading_decor_color' => '',
                    'button_color' => '',
                    'button_color2' => '',
                    'heading_size' => '',
                    'sub_heading_size' => '',
                    'text_size' => '',
                    'container' => 'container',
                    'style' => 'style1',
                    'social_buttons' => 'on'
                ), 
                $atts
            )
        );
         
        // Fill $html var with data
        $item_attr = $custom_css = '';

        $item_class = $id = "banner-item-".uniqid();

        if(isset(vc_build_link($link)['url']) && !empty(vc_build_link($link)['url'])) {
            $link = vc_build_link($link);
            if(empty($link['target'])) {
                $link['target'] = '_self';
            }
            if(empty($link['title'])) {
                $link['title'] = esc_html__('view more', 'imate');
            }
        } else {
            $link = '';
        }

        if(isset(vc_build_link($link2)['url']) && !empty(vc_build_link($link2)['url'])) {
            $link2 = vc_build_link($link2);
            if(empty($link2['target'])) {
                $link2['target'] = '_self';
            }
            if(empty($link2['title'])) {
                $link2['title'] = esc_html__('view more', 'imate');
            }
        } else {
            $link2 = '';
        }

        if($background_type == 'image' && isset(wp_get_attachment_image_src($background_image, 'full')[0])) {
            $item_attr = 'background-image: url('.esc_url(wp_get_attachment_image_src($background_image, 'full')[0]).');';
        }

        if($background_type == 'gradient' && !empty($background_gradient)) {
            $background_gradient = strip_tags(explode("||", $background_gradient)[1]);
            if(!empty($background_gradient)) {
                $item_attr = $background_gradient;
            }
        }

        if($background_type == 'color' && !empty($background_color)) {
            $item_attr = 'background-color: '.esc_attr($background_color).';';
        }

        if($bg_position != 'center center') {
            $item_attr .= 'background-position: '.esc_attr($bg_position).';';
        }

        $item_class .= ' '.$vertical_align.' '.$text_align;

        if(isset($text_color) && $text_color != 'custom') {
            $item_class .= ' '.$text_color;
        }

        if(isset($text_color) && $text_color == 'custom') {
            $custom_css .= '.'.$id.' {
                color: '.$text_color_hex.' !important;
            }';
        }

        if(isset($heading_size) && !empty($heading_size)) {
            $custom_css .= '.'.$id.' .cell .h {
                font-size: '.$heading_size.' !important;
            }';
        }

        if(isset($heading_color) && !empty($heading_color)) {
            $custom_css .= '.'.$id.' .cell .h {
                color: '.$heading_color.';
            }';
        }

        if(isset($heading_decor_color) && !empty($heading_decor_color)) {
            $custom_css .= '.'.$id.' .cell .h span {
                color: '.$heading_decor_color.';
            }';
        }

        if(isset($sub_heading_size) && !empty($sub_heading_size)) {
            $custom_css .= '.'.$id.' .cell .sub-h {
                font-size: '.$sub_heading_size.' !important;
            }';
        }

        if(isset($event_color) && !empty($event_color)) {
            $custom_css .= '.'.$id.' .cell .event-detail {
                color: '.$event_color.';
            }';
        }

        if(isset($sub_heading_color) && !empty($sub_heading_color)) {
            $custom_css .= '.'.$id.' .cell .sub-h {
                color: '.$sub_heading_color.';
            }';
        }

        if(isset($text_size) && !empty($text_size)) {
            $custom_css .= '.'.$id.' .cell .text {
                font-size: '.$text_size.' !important;
            }';
        }

        if($color_overlay == 'gradient' && !empty($color_overlay_gradient)) {
            $color_overlay_gradient = strip_tags(explode("||", $color_overlay_gradient)[1]);
            if(!empty($color_overlay_gradient)) {
                $custom_css .= '.'.$id.' .overlay {
                    '.$color_overlay_gradient.'
                    opacity: '.$opacity_overlay.' !important;
                }';
            }
        }

        if($color_overlay == 'color' && !empty($color_overlay_color)) {
            $custom_css .= '.'.$id.' .overlay {
                background-color: '.$color_overlay_color.';
                opacity: '.$opacity_overlay.' !important;
            }';
        }

        if(!empty($button_color)) {
            $custom_css .= '.'.$id.' .button-style1.link1:before {';
                $custom_css .= 'background-color: '.$button_color.';';
            $custom_css .= '}';
        }

        if(!empty($button_color2)) {
            $custom_css .= '.'.$id.' .button-style1.link2:before {';
                $custom_css .= 'color: '.$button_color2.';';
            $custom_css .= '}';
        }

        wp_enqueue_style('imate-custom-style', get_template_directory_uri() . '/css/custom_script.css');
        wp_add_inline_style( 'imate-custom-style', $custom_css );

        $video_html = '';
        if(!empty($video_url)) {
            wp_enqueue_script( 'video-background', get_template_directory_uri() . '/js/jquery.background-video.js', array('jquery') );
            wp_enqueue_script( 'video', get_template_directory_uri() . '/js/video.js', array('jquery') );

            $video_html = VideoUrlParser::get_background_video($video_url);
        }
        
        $html = '<div class="item '.esc_attr($item_class).'" style="'.esc_attr($item_attr).'">';
            $html .= $video_html;
            if(!empty($color_overlay)) {
                $html .= '<div class="overlay"></div>';
            }
            $html .= '<div class="'.esc_attr($container).'">';
                if($side_content == 'laptop_image' && !empty($laptop_image)) {
                    $html .= '<div class="laptop"><div style="background-image: url('.esc_url(wp_get_attachment_image_src($laptop_image, 'full')[0]).');"></div></div>';
                }
                if($side_content == 'contact_form' && !empty($contact_form)) {
                    $contact_form = str_replace(array('`{`', '``', '`}`'), array('[', '"', ']'), $contact_form);
                    $html .= '<div class="banner-form"><div class="cell"><div class="wrap">'.do_shortcode($contact_form).'</div></div></div>';
                }
                $html .= '<div class="cell">';
                    if($slide_type == 'event' && (!empty($event_date) || !empty($event_address))) {
                        $html .= '<div class="event-detail">';
                            if(!empty($event_date)) {
                                $html .= '<div class="d"><i class="material-design-icon-history-clock-button"></i><span>'.strip_tags($event_date).'</span></div>';
                            }
                            if(!empty($event_address)) {
                                $html .= '<div class="d"><i class="material-design-icon-map-placeholder"></i><span>'.strip_tags($event_address).'</span></div>';
                            }
                        $html .= '</div>';
                    }
                    if(!empty($sub_heading)) {
                        $html .= '<div class="sub-h decor-h"><span>'.wp_kses_post($sub_heading).'</span></div>';
                    }
                    if(!empty($heading)) {
                        $h_class = '';
                        if($heading_uppercase == 'on') {
                            $h_class = ' uppercase';
                        }
                        $heading = str_replace(array('{', '}'), array('<span>', '</span>'), $heading);
                        $html .= '<div class="h'.esc_attr($h_class).'">'.wp_kses_post($heading).'</div>';
                    }
                    if(!empty($content)) {
                        $html .= '<div class="text">'.wp_kses_post($content).'</div>';
                    }
                    if(!empty($link) || !empty($link2)) {
                        $html .= '<div class="link-area">';
                            if(!empty($link)) {
                                $html .= '<a href="'.esc_url($link['url']).'" class="button-style1 link1" title="'.esc_attr($link['title']).'" target="'.esc_attr($link['target']).'"><span>'.strip_tags($link['title']).'</span></a>';
                            }
                            if(!empty($link2)) {
                                $html .= '<a href="'.esc_url($link2['url']).'" class="button-style1 t2 link2" title="'.esc_attr($link2['title']).'" target="'.esc_attr($link2['target']).'"><span>'.strip_tags($link2['title']).'</span></a>';
                            }
                        $html .= '</div>';
                    }
                $html .= '</div>';
            $html .= '</div>';
        $html .= '</div>';

        return $html;
         
    }
     
} // End Element Class
 
 
// Element Class Init
new PT_Banner();    
if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
    class WPBakeryShortCode_PT_Banner extends WPBakeryShortCodesContainer {
    }
}
if ( class_exists( 'WPBakeryShortCode' ) ) {
    class WPBakeryShortCode_PT_Banner_Item extends WPBakeryShortCode {
    }
}

