<?php

// Element Description: PT Categories

class PT_Categories extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_categories_mapping' ) );
        add_shortcode( 'pt_categories', array( $this, 'pt_categories_html' ) );
        add_shortcode( 'pt_categories_item', array( $this, 'pt_categories_item_html' ) );
    }
     
    // Element Mapping
    public function pt_categories_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Categories", "imate"),
            "base" => "pt_categories",
            "as_parent" => array('only' => 'pt_categories_item'),
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-categories",
            "is_container" => true,
            "category" => esc_html__("By PT", "imate"),
            "params" => array(
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Style", "imate" ),
                    "param_name"  => "style",
                    "value"      => array(
                        esc_html__( "Default", "imate" ) => "default",
                        esc_html__( "Carousel", "imate" ) => "carousel",
                    ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Desktop", "imate" ),
                    "param_name"  => "desktop_cols",
                    "value"      => array(
                        esc_html__( "Col 1", "imate" ) => "1",
                        esc_html__( "Col 2", "imate" ) => "2",
                        esc_html__( "Col 3", "imate" ) => "3",
                        esc_html__( "Col 4", "imate" ) => "4",
                    ),
                    "std" => '3',
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Tablet", "imate" ),
                    "param_name"  => "tablet_cols",
                    "value"      => array(
                        esc_html__( "Col 1", "imate" ) => "1",
                        esc_html__( "Col 2", "imate" ) => "2",
                        esc_html__( "Col 3", "imate" ) => "3",
                        esc_html__( "Col 4", "imate" ) => "4",
                    ),
                    "std" => '2',
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Mobile", "imate" ),
                    "param_name"  => "mobile_cols",
                    "value"      => array(
                        esc_html__( "Col 1", "imate" ) => "1",
                        esc_html__( "Col 2", "imate" ) => "2",
                        esc_html__( "Col 3", "imate" ) => "3",
                        esc_html__( "Col 4", "imate" ) => "4",
                    ),
                    "std" => '1',
                ),
                array(
                    "type"        => "number",
                    "heading"     => esc_html__( "Transition speed", "imate" ),
                    "param_name"  => "speed",
                    "value"       => "300",
                    "min"         => "100",
                    "max"         => "10000",
                    "step"        => "100",
                    "suffix"      => "ms",
                    "dependency" => Array("element" => "style", "value" => "carousel" ),
                    'group' => esc_html__( 'Carousel Settings', 'imate' ),
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Autoplay Slides", "imate" ),
                    "param_name"  => "autoplay",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "label" => esc_html__( "Enable Autoplay", "imate" ),
                            "on"    => "Yes",
                            "off"   => "No",
                        ),
                    ),
                    "default_set" => true,
                    "dependency" => Array("element" => "style", "value" => "carousel" ),
                    'group' => esc_html__( 'Carousel Settings', 'imate' ),
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Navigation Arrows", "imate" ),
                    "param_name"  => "arrows",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => "Yes",
                            "off"   => "No",
                        ),
                    ),
                    "default_set" => true,
                    "dependency" => Array("element" => "style", "value" => "carousel" ),
                    'group' => esc_html__( 'Carousel Settings', 'imate' ),
                ),
                array(
                    "type"       => "number",
                    "heading"    => esc_html__( "Autoplay Speed", "imate" ),
                    "param_name" => "autoplay_speed",
                    "value"      => "5000",
                    "min"        => "100",
                    "max"        => "10000",
                    "step"       => "10",
                    "suffix"     => "ms",
                    "dependency" => Array("element" => "style", "value" => "carousel" ),
                    'group' => esc_html__( 'Carousel Settings', 'imate' ),
                ),
                array(
                    "type"       => "switch",
                    "heading"    => esc_html__( "Pause on hover", "imate" ),
                    "param_name" => "pauseohover",
                    "value"      => "on",
                    "options"    => array(
                        "on" => array(
                            "label" => esc_html__( "Pause the slider on hover", "imate" ),
                            "on"    => "Yes",
                            "off"   => "No",
                        ),
                    ),
                    "dependency" => Array("element" => "autoplay", "value" => "on" ),
                ),
                array(
                    "type" => "animation_style",
                    "heading" => esc_html__( "Animation In", "imate" ),
                    "param_name" => "animation",
                ),
                array(
                    'type' => 'css_editor',
                    'heading' => esc_html__( 'CSS box', 'imate' ),
                    'param_name' => 'css',
                    'group' => esc_html__( 'Design Options', 'imate' ),
                ),
            ),
            "js_view" => 'VcColumnView'
        ) );
        vc_map( array(
            "name" => esc_html__("Category item", "imate"),
            "base" => "pt_categories_item",
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-categories",
            "as_child" => array('only' => 'pt_categories'),
            "params" => array(
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Source", "imate" ),
                    "param_name"  => "categories_source",
                    'admin_label' => true,
                    "value"      => array(
                        esc_html__( "Blog", "imate" ) => "blog",
                        esc_html__( "Shop", "imate" ) => "shop",
                        esc_html__( "Portfolio", "imate" ) => "portfolio",
                        esc_html__( "Custom", "imate" ) => "custom",
                    ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Category", "imate" ),
                    "param_name"  => "categories_portfolio",
                    'admin_label' => true,
                    "value"       => get_all_portfolio_category(),
                    "dependency" => Array("element" => "categories_source", "value" => "portfolio" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Category", "imate" ),
                    "param_name"  => "categories_blog",
                    'admin_label' => true,
                    "value"       => get_all_blog_category(),
                    "dependency" => Array("element" => "categories_source", "value" => "blog" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Category", "imate" ),
                    "param_name"  => "categories_shop",
                    'admin_label' => true,
                    "value"       => get_all_product_category(),
                    "dependency" => Array("element" => "categories_source", "value" => "shop" ),
                ),
                array(
                    "type" => "textarea",
                    "heading" => esc_html__("Custom heading", "imate"),
                    "param_name" => "custom_heading",
                    "dependency" => Array( "element" => "categories_source", "value" => array( "portfolio", "blog", "shop" ) ),
                ),
                array(
                    "type" => "textarea",
                    "heading" => esc_html__("Custom description", "imate"),
                    "param_name" => "custom_desc",
                ),
                array(
                    "type" => "attach_image",
                    "heading" => esc_html__("Category image", "imate"),
                    "param_name" => "categories_image",
                    "edit_field_class" => 'vc_col-xs-12 vc_col-sm-6',
                ),
                array(
                    "type"       => "vc_link",
                    "heading"    => esc_html__( "Category link", "imate" ),
                    "param_name" => "categories_link",
                    'admin_label' => true,
                    "edit_field_class" => 'vc_col-xs-12 vc_col-sm-6',
                    "dependency" => Array( "element" => "categories_source", "value" => "custom" ),
                ),
                array(
                    "type"       => "colorpicker",
                    "heading"    => esc_html__( "Heading Color", "imate" ),
                    "param_name" => "heading_color",
                    "description" => esc_html__('(optional)', 'imate')
                ),
            )
        ) );
    }
     
    // Element HTML
    public function pt_categories_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                    'style' => 'default',
                    'count_items' => '9',
                    'desktop_cols' => '3',
                    'tablet_cols' => '2',
                    'speed' => '500',
                    'arrows' => 'on',
                    'autoplay' => 'on',
                    'autoplay_speed' => '3000',
                    'pauseohover' => 'on',
                    'mobile_cols' => '1',
                    'animation' => '',
                    'css' => '',
                ), 
                $atts
            )
        );

        $item_class = $id = 'categories-'.$uniq_id;

        if(!empty($css)) {
            $item_class .= ' '.vc_shortcode_custom_css_class( $css, ' ' );
        }

        $categories = array();
        $categories = pt_the_shortcodes( $categories, $content );

        if($style == 'carousel') {
            if($autoplay == 'on') {
                $autoplay = 'true';
            } else {
                $autoplay = 'false';
            }
            if($pauseohover == 'on') {
                $pauseohover = 'true';
            } else {
                $pauseohover = 'false';
            }
            if($arrows == 'on') {
                $arrows = 'true';
            } else {
                $arrows = 'false';
            }

            wp_enqueue_style( 'owl-carousel-css', get_template_directory_uri() . '/css/owl.carousel.css');
            wp_enqueue_script( 'owl-carousel-js', get_template_directory_uri() . '/js/owl.carousel.min.js', array('jquery') );
            wp_enqueue_script( 'imate-script', get_template_directory_uri() . '/js/script.js' );

            wp_add_inline_script('imate-script', "jQuery(document).ready(function(jQuery) {
                jQuery('.".esc_attr($id)." .categories').each(function(){
                    var head_slider = jQuery(this);
                    if(jQuery(this).find('.item').length > 1){
                        head_slider.addClass('owl-carousel').owlCarousel({
                            loop:true,
                            items:1,
                            nav: ".esc_js($arrows).",
                            dots: false,
                            autoplay: ".esc_js($autoplay).",
                            autoplayTimeout: ".esc_js($autoplay_speed).",
                            autoplayHoverPause: ".esc_js($pauseohover).",
                            smartSpeed: ".esc_js($speed).",
                            autoHeight: true,
                            navClass: ['owl-prev fa fa-angle-left','owl-next fa fa-angle-right'],
                            autoHeight: true,
                            navText: false,
                            margin: 30,
                            responsive:{
                                0:{
                                    items:1
                                },
                                768:{
                                    items:".esc_js($mobile_cols)."
                                },
                                992:{
                                    items:".esc_js($tablet_cols)."
                                },
                                1200:{
                                    items:".esc_js($desktop_cols)."
                                },
                            }
                        });
                    }
                });
            });");
        } else {
            $cols_css = 'col-xs-'.(12/$mobile_cols).' col-sm-'.(12/$tablet_cols).' col-md-'.(12/$desktop_cols);
        }
        
        ob_start();

        if(count($categories) > 0) { ?>
            <div class="categories-area <?php echo esc_attr($item_class) ?>">
                <div class="categories row">
                    <?php foreach ($categories as $key => $course) { 
                        extract(
                            shortcode_atts(
                                array(
                                    'categories_source' => 'content',
                                    'categories_portfolio' => '',
                                    'categories_blog' => '',
                                    'categories_shop' => '',
                                    'custom_heading' => '',
                                    'custom_desc' => '',
                                    'categories_image' => '',
                                    'categories_link' => '',
                                    'heading_color' => '',
                                ), 
                                $course
                            )
                        );

                        $name = $desc = '';

                        $item_css = $item_id = uniqid('category-');

                        if(!empty($categories_blog)) {
                            $id = $categories_blog;

                            $name = get_term( (int) $id, 'category' )->name;
                            $desc = get_term( (int) $id, 'category' )->description;
                            $link = get_term_link( (int) $id, 'category' );

                            if(function_exists('category_image_src') && category_image_src( array( 'term_id' => $id, 'size' => 'large') , false )) {
                                $image_src = category_image_src( array( 'term_id' => $id, 'size' => 'large') , false );
                            }
                        } else if(!empty($categories_portfolio)) {
                            $id = $categories_portfolio;

                            $name = get_term( (int) $id, 'fw-portfolio-category' )->name;
                            $desc = get_term( (int) $id, 'fw-portfolio-category' )->description;
                            $link = get_term_link( (int) $id, 'fw-portfolio-category' );

                            if(function_exists('category_image_src') && category_image_src( array( 'term_id' => $id, 'size' => 'large') , false )) {
                                $image_src = category_image_src( array( 'term_id' => $id, 'size' => 'large') , false );
                            }
                        } else if(!empty($categories_shop)) {
                            $id = $categories_shop;

                            $name = get_term( (int) $id, 'product_cat' )->name;
                            $desc = get_term( (int) $id, 'product_cat' )->description;
                            $link = get_term_link( (int) $id, 'product_cat' );

                            $thumbnail_id = get_woocommerce_term_meta( $id, 'thumbnail_id', true ); 
                            $image_src = wp_get_attachment_url( $thumbnail_id );
                        }

                        if(!empty($custom_heading)) {
                            $name = $custom_heading;
                        }

                        if(!empty($custom_desc)) {
                            $desc = $custom_desc;
                        }

                        if(isset(wp_get_attachment_image_src($categories_image, 'full')[0]) && !empty(wp_get_attachment_image_src($categories_image, 'full')[0])) {
                            $image_src = wp_get_attachment_image_src($categories_image, 'full')[0];
                        }

                        if(isset(vc_build_link($categories_link)['url']) && !empty(vc_build_link($categories_link)['url'])) {
                            $link = vc_build_link($categories_link)['url'];
                            $name = vc_build_link($categories_link)['title'];
                        }

                        if(!empty($image_src)) {
                            $item_attr = 'background-image: url('.esc_url($image_src).');';
                        }

                        if(isset($heading_color) && !empty($heading_color)) {
                            $custom_css .= '.'.$item_id.' {
                                color: '.$heading_color.';
                            }';
                        }

                        if(function_exists('iconv_strlen') && iconv_strlen($desc, 'UTF-8') > 110) {
                            $desc = mb_substr($desc, 0, 110).'...';
                        } else if(!function_exists('iconv_strlen')) {
                            $desc = mb_substr($desc, 0, 110);
                        }

                        if($style != 'carousel') {
                            $item_css = ' '.$cols_css;
                        }

                        if(!empty($custom_css)) {
                            wp_enqueue_style('imate-custom-style', get_template_directory_uri() . '/css/custom_script.css');
                            wp_add_inline_style( 'imate-custom-style', $custom_css );
                        }
                    ?>
                        <div class="item <?php echo esc_attr($item_css) ?>">
                            <a href="<?php echo esc_url($link) ?>">
                                <span class="image" style="<?php echo esc_attr($item_attr) ?>" ></span>
                                <span class="content">
                                    <span class="name"><?php echo wp_kses_post($name) ?></span>
                                    <?php if(!empty($desc)) { ?>
                                        <span class="desc"><?php echo wp_kses_post($desc) ?></span>
                                    <?php } ?>
                                </span>
                            </a>
                        </div>
                    <?php } ?>
                </div>
            </div>
        <?php }
         
        return ob_get_clean();
         
    }

    // Element HTML
    public function pt_categories_item_html( $atts ) { 
        return false;
    }
     
} // End Element Class
 
 
// Element Class Init
new PT_Categories();    
if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
    class WPBakeryShortCode_PT_Categories extends WPBakeryShortCodesContainer {
    }
}
if ( class_exists( 'WPBakeryShortCode' ) ) {
    class WPBakeryShortCode_PT_Categories_Item extends WPBakeryShortCode {
    }
}

