<?php

// Element Description: PT Event Shedule

class PT_Event_Schedule extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_event_schedule_mapping' ) );
        add_shortcode( 'pt_event_schedule', array( $this, 'pt_event_schedule_html' ) );
        add_shortcode( 'pt_event_schedule_item', array( $this, 'pt_event_schedule_item_html' ) );
        add_shortcode( 'pt_event_schedule_item_item', array( $this, 'pt_event_schedule_item_item_html' ) );
    }
     
    // Element Mapping
    public function pt_event_schedule_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Event Shedule", "imate"),
            "base" => "pt_event_schedule",
            "as_parent" => array('only' => 'pt_event_schedule_item'),
            "content_element" => true,
            "show_settings_on_create" => true,
            "is_container" => true,
            "icon" => "shortcode-icon-event-schedule",
            "category" => esc_html__("By PT", "imate"),
            "params" => array(
                
            ),
            'js_view' => 'VcColumnView',
        ) );
        vc_map( array(
            "name" => esc_html__("Event Shedule Item", "imate"),
            "base" => "pt_event_schedule_item",
            "as_parent" => array('only' => 'pt_event_schedule_item_item'),
            "content_element" => true,
            "is_container" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-event-schedule",
            "as_child" => array('only' => 'pt_event_schedule'),
            "js_view" => 'VcColumnView',
            "params" => array(
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Date", "imate"),
                    "param_name" => "date",
                ),
            )
        ) );
        vc_map( array(
            "name" => esc_html__("Event Shedule Item", "imate"),
            "base" => "pt_event_schedule_item_item",
            "content_element" => true,
            "is_container" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-event-schedule",
            "as_child" => array('only' => 'pt_event_schedule_item'),
            "params" => array(
                array(
                    "type" => "attach_image",
                    "heading" => esc_html__("Image", "imate"),
                    "param_name" => "image",
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Title", "imate"),
                    "param_name" => "title",
                    "admin_label" => true,
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Time", "imate"),
                    "param_name" => "time",
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Lector", "imate"),
                    "param_name" => "lector",
                ),
                array(
                    "type" => "textarea",
                    "heading" => esc_html__("Description", "imate"),
                    "param_name" => "desc",
                ),
                array(
                    "type" => "vc_link",
                    "heading" => esc_html__("Link", "imate"),
                    "param_name" => "link",
                ),
            )
        ) );
    }
     
    public function pt_event_schedule_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                ), 
                $atts
            )
        );


        $area_class = $id = uniqid('event-schedule');

        wp_enqueue_style( 'owl-carousel-css', get_template_directory_uri() . '/css/owl.carousel.css');
        wp_enqueue_script( 'owl-carousel-js', get_template_directory_uri() . '/js/owl.carousel.min.js', array('jquery'), true );
        wp_enqueue_script( 'owl-linked-js', get_template_directory_uri() . '/js/owl.linked.js', array('jquery'), true );

        wp_enqueue_script( 'imate-script', get_template_directory_uri() . '/js/script.js' );

        wp_add_inline_script('imate-script', "jQuery(document).ready(function(jQuery) {
            jQuery('.".esc_attr($id)."').pt_event_schedule();
        });");

        ob_start();
        ?>

        <div class="event-schedule-area <?php echo esc_attr($area_class) ?>">
            <div class="event-dates"></div>
            <div class="event-schedule-contents"><?php echo do_shortcode($content) ?></div>
        </div>
        
        <?php
        return ob_get_clean();
    }

    public function pt_event_schedule_item_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'date' => '',
                ), 
                $atts
            )
        );
         
        // Fill $html var with data
        $item_attr = $item_class = $item_style = '';

        ob_start();
        ?>

        <div class="event-schedule-content" data-date="<?php echo esc_attr($date) ?>">
            <?php echo do_shortcode($content) ?>
        </div>
    
        <?php
        return ob_get_clean();
    }

    public function pt_event_schedule_item_item_html( $atts ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'image' => '',
                    'title' => '',
                    'time' => '',
                    'lector' => '',
                    'desc' => '',
                    'link' => ''
                ), 
                $atts
            )
        );
         
        // Fill $html var with data
        $item_attr = $item_class = $item_style = '';

        if(isset(wp_get_attachment_image_src($image, 'full')[0])) {
            $item_attr = 'background-image: url('.esc_url(wp_get_attachment_image_src($image, 'full')[0]).');';
        }

        if(isset(vc_build_link($link)['url']) && !empty(vc_build_link($link)['url'])) {
            $link = vc_build_link($link);

            if(empty($link['target'])) {
                $link['target'] = '_self';
            }
        } else {
            $link = '';
        }

        ob_start();
        ?>

        <div class="event-schedule-item">
            <?php if(!empty($item_attr)) { ?>
                <div class="image" style="<?php echo esc_attr($item_attr) ?>">
                    <?php if(!empty($link)) { ?>
                        <a href="<?php echo esc_url($link['url']) ?>" target="<?php echo esc_attr($link['target']) ?>"></a>
                    <?php } ?>
                </div>
            <?php } ?>
            <div class="content">
                <?php if(!empty($title)) { ?>
                    <h5>
                        <?php if(!empty($link)) { ?>
                            <a href="<?php echo esc_url($link['url']) ?>" target="<?php echo esc_attr($link['target']) ?>">
                        <?php } ?>
                            <?php echo wp_kses_post($title); ?>
                        <?php if(!empty($link)) { ?>
                            </a>
                        <?php } ?>
                        
                    </h5>
                <?php } if(!empty($time) || !empty($lector)) { ?>
                    <div class="detail">
                        <?php if(!empty($time)) { ?>
                            <div class="d"><i class="material-design-icon-history-clock-button"></i><span><?php echo strip_tags($time) ?></span></div>
                        <?php } if(!empty($lector)) { ?>
                            <div class="d"><i class="material-design-icon-graduate-cap"></i><span><?php echo strip_tags($lector) ?></span></div>
                        <?php } ?>
                    </div>
                <?php } if(!empty($desc)) { ?>
                    <div class="desc"><?php echo wp_kses_post($desc) ?></div>
                <?php } ?>
            </div>
        </div>
    
        <?php
        return ob_get_clean();
    }
     
} // End Element Class
 
 
// Element Class Init
new PT_Event_Schedule();    
if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
    class WPBakeryShortCode_PT_Event_Schedule extends WPBakeryShortCodesContainer {
    }
}
if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
    class WPBakeryShortCode_PT_Event_Schedule_Item extends WPBakeryShortCodesContainer {
    }
}
if ( class_exists( 'WPBakeryShortCode' ) ) {
    class WPBakeryShortCode_PT_Event_Schedule_Item_Item extends WPBakeryShortCode {
    }
}

