<?php

// Element Description: PT Icon Box

class PT_Icon_Box extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_icon_box_mapping' ) );
        add_shortcode( 'pt_icon_box', array( $this, 'pt_icon_box_html' ) );
        add_shortcode( 'pt_icon_box_item', array( $this, 'pt_icon_box_item_html' ) );
    }
     
    // Element Mapping
    public function pt_icon_box_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Icon Box", "imate"),
            "base" => "pt_icon_box",
            "as_parent" => array('only' => 'pt_icon_box_item'),
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-icon-box",
            "is_container" => true,
            "category" => esc_html__("By PT", "imate"),
            "params" => array(
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Cols", "imate" ),
                    "param_name"  => "cols",
                    "value"      => array(
                        esc_html__( "Inline", "imate" ) => "inline",
                        esc_html__( "Col 1", "imate" ) => "col1",
                        esc_html__( "Col 2", "imate" ) => "col2",
                        esc_html__( "Col 3", "imate" ) => "col3",
                        esc_html__( "Col 4", "imate" ) => "col4",
                    ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Align", "imate" ),
                    "param_name"  => "align",
                    "value"      => array(
                        esc_html__( "Left", "imate" ) => "tal",
                        esc_html__( "Center", "imate" ) => "tac",
                        esc_html__( "Right", "imate" ) => "tar",
                    ),
                    "std" => 'tac',
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__( "Icon Color", "imate" ),
                    "param_name" => "icon_color",
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__( "Num Color", "imate" ),
                    "param_name" => "num_color",
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__( "Heading Color", "imate" ),
                    "param_name" => "heading_color",
                ),
                array(
                    'type' => 'css_editor',
                    'heading' => esc_html__( 'CSS box', 'imate' ),
                    'param_name' => 'css',
                    'group' => esc_html__( 'Design Options', 'imate' ),
                ),
                array(
                    "type" => "animation_style",
                    "heading" => esc_html__( "Animation In", "imate" ),
                    "param_name" => "animation",
                ),
            ),
            "js_view" => 'VcColumnView'
        ) );
        vc_map( array(
            "name" => esc_html__("Icon Box item", "imate"),
            "base" => "pt_icon_box_item",
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-icon-box",
            "as_child" => array('only' => 'pt_icon_box'),
            "params" => array(
                array(
                    'type' => 'dropdown',
                    'heading' => esc_html__( 'Icon library', 'imate' ),
                    'value' => array(
                        esc_html__( 'Font Awesome', 'imate' ) => 'fontawesome',
                        esc_html__( 'Open Iconic', 'imate' ) => 'openiconic',
                        esc_html__( 'Typicons', 'imate' ) => 'typicons',
                        esc_html__( 'Entypo', 'imate' ) => 'entypo',
                        esc_html__( 'Linecons', 'imate' ) => 'linecons',
                        esc_html__( 'Mono Social', 'imate' ) => 'monosocial',
                        esc_html__( 'Material', 'imate' ) => 'material',
                    ),
                    'admin_label' => true,
                    'param_name' => 'type',
                    'description' => esc_html__( 'Select icon library.', 'imate' ),
                ),
                array(
                    'type' => 'iconpicker',
                    'heading' => esc_html__( 'Icon', 'imate' ),
                    'param_name' => 'icon_fontawesome',
                    'value' => 'fa fa-adjust',
                    'settings' => array(
                        'emptyIcon' => false,
                        'iconsPerPage' => 4000,
                    ),
                    'dependency' => array(
                        'element' => 'type',
                        'value' => 'fontawesome',
                    ),
                    'description' => esc_html__( 'Select icon from library.', 'imate' ),
                ),
                array(
                    'type' => 'iconpicker',
                    'heading' => esc_html__( 'Icon', 'imate' ),
                    'param_name' => 'icon_openiconic',
                    'value' => 'vc-oi vc-oi-dial',
                    'settings' => array(
                        'emptyIcon' => false,
                        'type' => 'openiconic',
                        'iconsPerPage' => 4000,
                    ),
                    'dependency' => array(
                        'element' => 'type',
                        'value' => 'openiconic',
                    ),
                    'description' => esc_html__( 'Select icon from library.', 'imate' ),
                ),
                array(
                    'type' => 'iconpicker',
                    'heading' => esc_html__( 'Icon', 'imate' ),
                    'param_name' => 'icon_typicons',
                    'value' => 'typcn typcn-adjust-brightness',
                    'settings' => array(
                        'emptyIcon' => false,
                        'type' => 'typicons',
                        'iconsPerPage' => 4000,
                    ),
                    'dependency' => array(
                        'element' => 'type',
                        'value' => 'typicons',
                    ),
                    'description' => esc_html__( 'Select icon from library.', 'imate' ),
                ),
                array(
                    'type' => 'iconpicker',
                    'heading' => esc_html__( 'Icon', 'imate' ),
                    'param_name' => 'icon_entypo',
                    'value' => 'entypo-icon entypo-icon-note',
                    'settings' => array(
                        'emptyIcon' => false,
                        'type' => 'entypo',
                        'iconsPerPage' => 4000,
                    ),
                    'dependency' => array(
                        'element' => 'type',
                        'value' => 'entypo',
                    ),
                ),
                array(
                    'type' => 'iconpicker',
                    'heading' => esc_html__( 'Icon', 'imate' ),
                    'param_name' => 'icon_linecons',
                    'value' => 'vc_li vc_li-heart',
                    'settings' => array(
                        'emptyIcon' => false,
                        'type' => 'linecons',
                        'iconsPerPage' => 4000,
                    ),
                    'dependency' => array(
                        'element' => 'type',
                        'value' => 'linecons',
                    ),
                    'description' => esc_html__( 'Select icon from library.', 'imate' ),
                ),
                array(
                    'type' => 'iconpicker',
                    'heading' => esc_html__( 'Icon', 'imate' ),
                    'param_name' => 'icon_monosocial',
                    'value' => 'vc-mono vc-mono-fivehundredpx',
                    'settings' => array(
                        'emptyIcon' => false,
                        'type' => 'monosocial',
                        'iconsPerPage' => 4000,
                    ),
                    'dependency' => array(
                        'element' => 'type',
                        'value' => 'monosocial',
                    ),
                    'description' => esc_html__( 'Select icon from library.', 'imate' ),
                ),
                array(
                    'type' => 'iconpicker',
                    'heading' => esc_html__( 'Icon', 'imate' ),
                    'param_name' => 'icon_material',
                    'value' => 'vc-material vc-material-cake',
                    'settings' => array(
                        'emptyIcon' => false,
                        'type' => 'material',
                        'iconsPerPage' => 4000,
                    ),
                    'dependency' => array(
                        'element' => 'type',
                        'value' => 'material',
                    ),
                    'description' => esc_html__( 'Select icon from library.', 'imate' ),
                ),
                array(
                    "type" => "textarea",
                    "heading" => esc_html__("Heading", "imate"),
                    "param_name" => "heading",
                    "admin_label" => true,
                ),
                array(
                    "type" => "textarea",
                    "heading" => esc_html__("Description", "imate"),
                    "param_name" => "desc",
                ),
            )
        ) );
    }
     
     
    // Element HTML
    public function pt_icon_box_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                    'cols' => 'inline',
                    'align' => 'tac',
                    'num_color' => '',
                    'heading_color' => '',
                    'css' => '',
                    'animation' => ''
                ), 
                $atts
            )
        );

        $item_class = $id = uniqid('icon-box-');

        $item_class .= ' '.$align;

        if(!empty($css)) {
            $item_class .= ' '.vc_shortcode_custom_css_class( $css, ' ' );
        }

        if(!empty($animation)) {
            $item_class .= ' '.$this->getCSSAnimation($animation);
        }

        $html = "";

        // Fill $html var with data
        $custom_css = "";

        if(!empty($num_color)) {
            $custom_css .= '.'.$id.' .icon-box-item .num-wrap {
                color: '.$num_color.';
            }';
        }

        if(!empty($heading_color)) {
            $custom_css .= '.'.$id.' .icon-box-item .h {
                color: '.$heading_color.';
            }';
        }

        if(!empty($custom_css)) {
            wp_enqueue_style( 'imate-custom-style', get_template_directory_uri() . '/css/custom_script.css' );
            wp_add_inline_style( 'imate-custom-style', $custom_css );
        }

        if($cols != 'inline') {
            $item_class .= ' row';
        }

        ob_start();

        if(!empty($content)) {
            $content = str_replace('[pt_icon_box_item', '[pt_icon_box_item cols="'.esc_attr($cols).'"', $content);
        }
        ?>

        <div class="icon-box <?php echo esc_attr($item_class) ?>">
            <?php echo do_shortcode($content) ?>
        </div>
         
        <?php
        return ob_get_clean();
         
    }

    // Element HTML
    public function pt_icon_box_item_html( $atts ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'cols' => 'inline',
                    'type' => 'fontawesome',
                    'icon_fontawesome' => 'fa fa-adjust',
                    'icon_openiconic' => 'vc-oi vc-oi-dial',
                    'icon_typicons' => 'typcn typcn-adjust-brightness',
                    'icon_entypo' => 'entypo-icon entypo-icon-note',
                    'icon_linecons' => 'vc_li vc_li-heart',
                    'icon_monosocial' => 'vc-mono vc-mono-fivehundredpx',
                    'icon_material' => 'vc-material vc-material-cake',
                    'icon_color' => '',
                    'heading' => '',
                    'desc' => '',
                ), 
                $atts
            )
        );

        $icon = 'icon_'.$type;

        switch ($cols) {
            case 'col1':
                $cols_class = "col-xs-12";
                break;
            case 'col2':
                $cols_class = "col-xs-12 col-sm-6 col-md-6";
                break;
            case 'col3':
                $cols_class = "col-xs-12 col-sm-4 col-md-4";
                break;
            case 'col4':
                $cols_class = "col-xs-12 col-sm-4 col-md-3";
                break;
            
            default:
                $cols_class = "";
                break;
        }

        ob_start();
        
        if(!empty($cols_class)) { ?>
            <div class="<?php echo esc_attr($cols_class) ?>">
        <?php } ?>
        
            <div class="icon-box-item">
                <div class="wrap">
                    <?php if(isset($$icon) && !empty($$icon)) { ?>
                        <div class="icon <?php echo esc_attr($$icon) ?>"></div>
                    <?php } if(!empty($heading)) { ?>
                        <div class="h"><?php echo wp_kses_post($heading) ?></div>
                    <?php } if(!empty($desc)) { ?>
                        <div class="desc"><?php echo wp_kses_post($desc) ?></div>
                    <?php } ?>
                </div>
            </div>

        <?php if(!empty($cols_class)) { ?>
            </div>
        <?php }

        return ob_get_clean();
         
    }
     
} // End Element Class
 
 
// Element Class Init
new PT_Icon_Box();    
if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
    class WPBakeryShortCode_PT_Icon_Box extends WPBakeryShortCodesContainer {
    }
}
if ( class_exists( 'WPBakeryShortCode' ) ) {
    class WPBakeryShortCode_PT_Icon_Box_Item extends WPBakeryShortCode {
    }
}

