<?php

// Element Description: PT Portfolio

class PT_Portfolio_Items extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_portfolio_mapping' ) );
        add_shortcode( 'pt_portfolio', array( $this, 'pt_portfolio_html' ) );
    }
     
    // Element Mapping
    public function pt_portfolio_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Portfolio", "imate"),
            "base" => "pt_portfolio",
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-portfolio",
            "is_container" => true,
            "category" => esc_html__("By PT", "imate"),
            "params" => array(
                array(
                    "type"        => "textfield",
                    "heading"     => esc_html__( "Uniq ID", "imate" ),
                    "param_name"  => "uniq_id",
                    "value"       => uniqid(),
                ),
                array(
                    "type"        => "number",
                    "heading"     => esc_html__( "Count items", "imate" ),
                    "param_name"  => "count_items",
                    "value"       => '9',
                    "admin_label" => true,
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Type", "imate" ),
                    "param_name"  => "type",
                    "admin_label" => true,
                    "value"      => array(
                        esc_html__( "Grid", "imate" ) => "grid",
                        esc_html__( "Masonry", "imate" ) => "masonry",
                        esc_html__( "Packery", "imate" ) => "packery",
                    ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Hover effect", "imate" ),
                    "param_name"  => "hover_effect",
                    "admin_label" => true,
                    "value"      => array(
                        esc_html__( "Hover 1", "imate" ) => "style1",
                        esc_html__( "Hover 2", "imate" ) => "style2",
                    ),
                    "dependency" => Array( "element" => "type", "value" => array( "grid", "masonry", "packery" ) ),
                    "std" => 'style1',
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Colums", "imate" ),
                    "param_name"  => "cols",
                    "admin_label" => true,
                    "value"      => array(
                        esc_html__( "Col 1", "imate" ) => "1",
                        esc_html__( "Col 2", "imate" ) => "2",
                        esc_html__( "Col 3", "imate" ) => "3",
                        esc_html__( "Col 4", "imate" ) => "4",
                    ),
                    "std" => '3',
                    "dependency"  => Array( "element" => "type", "value" => array("grid", "masonry", "packery" ) ),
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Gap", "imate" ),
                    "param_name"  => "gap",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => "Yes",
                            "off"   => "No",
                        ),
                    ),
                    "default_set" => true,
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Filter buttons", "imate" ),
                    "param_name"  => "filter_buttons",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "imate" ),
                            "off"   => esc_html__( "Off", "imate" ),
                        ),
                    ),
                    "default_set" => true,
                    "dependency"  => Array( "element" => "type", "value" => array( "grid", "masonry", "packery" ) ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Filter buttons align", "imate" ),
                    "param_name"  => "filter_buttons_align",
                    "dependency"  => Array( "element" => "filter_buttons", "value" => array( "on" ) ),
                    "value"      => array(
                        esc_html__('Left', 'imate') => 'tal',
                        esc_html__('Center', 'imate') => 'tac',
                        esc_html__('Right', 'imate') => 'tar',
                    ),
                    "std" => "tac",
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Navigation", "imate" ),
                    "param_name"  => "navigation",
                    "value"      => array(
                        esc_html__( "None", "imate" ) => "none",
                        esc_html__( "Load More", "imate" ) => "load_more",
                        esc_html__( "Pagination", "imate" ) => "pagination",
                    ),
                    "dependency" => Array( "element" => "type", "value" => array( "grid", "masonry", "packery", "masonry_type2" ) ),
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Popup mode", "imate" ),
                    "param_name"  => "popup_mode",
                    "value"       => "on",
                    "admin_label" => true,
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "imate" ),
                            "off"   => esc_html__( "Off", "imate" ),
                        ),
                    ),
                    "default_set" => true,
                    "dependency" => Array( "element" => "hover_effect", "value" => array( "style1" ) ),
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Heading", "imate" ),
                    "param_name"  => "show_heading",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "imate" ),
                            "off"   => esc_html__( "Off", "imate" ),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__( "Fields", "imate" ),
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Category", "imate" ),
                    "param_name"  => "show_category",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "imate" ),
                            "off"   => esc_html__( "Off", "imate" ),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__( "Fields", "imate" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Order by", "imate" ),
                    "param_name"  => "orderby",
                    "value"      => array(
                        esc_html__('Default', 'imate') => 'post__in',
                        esc_html__('Author', 'imate') => 'author',
                        esc_html__('Date', 'imate') => 'date',
                        esc_html__('ID', 'imate') => 'ID',
                        esc_html__('Title', 'imate') => 'title',
                    ),
                    "group"       => esc_html__( "Sorting", "imate" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Order", "imate" ),
                    "param_name"  => "order",
                    "value"      => array(
                        esc_html__('Ascending order', 'imate') => 'ASC',
                        esc_html__('Descending order', 'imate') => 'DESC',
                    ),
                    "group"       => esc_html__( "Sorting", "imate" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Source", "imate" ),
                    "param_name"  => "source",
                    "value"      => array(
                        esc_html__( "---", "imate" ) => "",
                        esc_html__( "Items", "imate" ) => "items",
                        esc_html__( "Categories", "imate" ) => "categories",
                    ),
                    "group"       => esc_html__( "Source", "imate" ),
                ),
                array(
                    "type"        => "dropdown_multi",
                    "heading"     => esc_html__( "Items", "imate" ),
                    "param_name"  => "items",
                    "dependency"  => Array( "element" => "source", "value" => array( "items" ) ),
                    "value"       => get_all_portfolio_items(),
                    "group"       => esc_html__( "Source", "imate" ),
                ),
                array(
                    "type"        => "dropdown_multi",
                    "heading"     => esc_html__( "Category", "imate" ),
                    "param_name"  => "categories",
                    "dependency"  => Array( "element" => "source", "value" => array( "categories" ) ),
                    "value"       => get_all_portfolio_category(),
                    "group"       => esc_html__( "Source", "imate" ),
                ),
                array(
                    "type" => "animation_style",
                    "heading" => esc_html__( "Animation In", "imate" ),
                    "param_name" => "animation",
                ),
                array(
                    'type' => 'css_editor',
                    'heading' => esc_html__( 'CSS box', 'imate' ),
                    'param_name' => 'css',
                    'group' => esc_html__( 'Design Options', 'imate' ),
                ),
            ),
        ) );
    }
     
     
    // Element HTML
    public function pt_portfolio_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                    'count_items' => '9', 
                    'type' => 'grid',
                    'gap' => 'on',
                    'cols' => '3',
                    'popup_mode' => 'on',
                    'video_mode' => 'off',
                    'hover_effect' => 'style1',
                    'filter_buttons' => 'on',
                    'filter_buttons_align' => 'tac',
                    'navigation' => 'none',
                    'show_heading' => 'on',
                    'show_category' => 'on',
                    'orderby' => 'post__in',
                    'order' => 'ASC',
                    'source' => '',
                    'items' => '',
                    'categories' => '',
                    'source' => '',
                    'animation' => '',
                    'infinite_loop' => 'on',
                    'arrows' => 'on',
                    'speed' => '300',
                    'autoplay' => 'on',
                    'autoplay_speed' => '5000',
                    'css' => ''
                ), 
                $atts
            )
        );

        $animation = $this->getCSSAnimation($animation);

        $wrap_id = 'portfolio-'.$uniq_id;

        if(is_front_page()) {
            $paged = (get_query_var('page')) ? get_query_var('page') : 1;
        } else {
            $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
        }

        $tax_query = array();

        $categories_s = '';
        if ( !empty($categories) && $categories != '0' ) {
            $categories_s = explode(',', $categories);
            $tax_query = array(
                array(
                    'taxonomy' => 'fw-portfolio-category',
                    'field'    => 'id',
                    'terms'    => $categories_s
                )
            );
        }
        if($items) {
            $items = explode(',', $items);
        } else {
            $items = '';
        }
        $args = array(
            'post__in'        => $items,
            'posts_per_page'  => $count_items,
            'paged'           => $paged,
            'orderby'         => $orderby,
            'order'           => $order,
            'post_type'       => 'fw-portfolio',
            'post_status'     => 'publish',
            'tax_query'       => $tax_query
        );

        $porfolio_array = new WP_Query( $args );

        $item_num = $max_num_pages = 0;
        $max_num_pages = $porfolio_array->max_num_pages;

        $html = $wrap_classes = $custom_css = $area_class = '';

        if($type == 'masonry_type2') {
            $cols = '2';
            $filter_buttons = 'off';
        }

        switch ($cols) {
            case '1':
                $item_col = "col-xs-12";
                break;
            case '2':
                $item_col = "col-xs-12 col-sm-6 col-md-6";
                $mobile_cols = "1";
                $tablet_cols = "2";
                $desktop_cols = "2";
                break;
            case '3':
                $item_col = "col-xs-12 col-sm-4 col-md-4";
                $mobile_cols = "1";
                $tablet_cols = "2";
                $desktop_cols = "3";
                break;
            case '4':
                $item_col = "col-xs-12 col-sm-4 col-md-3";
                $mobile_cols = "1";
                $tablet_cols = "2";
                $desktop_cols = "4";
                break;
            
            default:
                $item_col = "";
                break;
        }

        $category_array = array();
        if($items) {
            $i = 0;
            while ( $porfolio_array->have_posts() ) : $porfolio_array->the_post();
                $id = get_the_ID();
                $category_array[$i] = array();
                foreach (wp_get_post_terms( $id, 'fw-portfolio-category') as $key2 => $s_item) {
                    $category_array[$i][$key2] = array('slug' => $s_item->slug , 'name' => $s_item->name);
                }
                $i++;
            endwhile;

            $arrOut = array();
            foreach($category_array as $subArr){
                $arrOut = array_merge($arrOut,$subArr);
            }

            $category_array = array_map( 'unserialize', array_unique( array_map( 'serialize', $arrOut)));
        } else if(is_array($categories_s) && count($categories_s) > 0) {
            $args     = array(
                'hide_empty' => true,
                'include' => $categories_s
            );
            $taxonomy = 'fw-portfolio-category';
            $terms     = get_terms( $taxonomy, $args );
            if(!empty($terms) && !is_wp_error( $terms )) {
                foreach($terms as $s_item) { 
                    $category_array[] = array('slug' => $s_item->slug , 'name' => $s_item->name);
                }
            }
        } else {
            $args     = array(
                'hide_empty' => true,
            );
            $taxonomy = 'fw-portfolio-category';
            $terms     = get_terms( $taxonomy, $args );
            if(!empty($terms)) {
                foreach($terms as $s_item) { 
                    $category_array[] = array('slug' => $s_item->slug , 'name' => $s_item->name);
                }
            }
        }

        if($popup_mode == 'on' || $hover_effect == 'style2') {
            $wrap_classes .= 'popup-gallery';
        }

        wp_enqueue_style('imate-custom-style', get_template_directory_uri() . '/css/custom_script.css');
        wp_add_inline_style( 'imate-custom-style', $custom_css );

        $html = "";

        if($type == 'justified') {
            wp_enqueue_script( 'justifiedGallery', get_template_directory_uri() . '/js/jquery.justifiedGallery.js', array('jquery'), true );

            $wrap_classes .= ' disable-iso';
            $filter_buttons = 'off';
            $item_col = '';
        }

        if(empty($gap)) {
            $gap = 'on';
        }

        if(!empty($css)) {
            $area_class .= ' '.vc_shortcode_custom_css_class( $css );
        }

        $html .= '<div class="portfolio-array'.esc_attr($area_class).'">';
            if(is_array($porfolio_array->posts) && count($porfolio_array->posts) > 0) {
                if(is_array($category_array) && $filter_buttons == "on" && count($category_array) > 1) {
                    $html .= '<div class="filter-button-group '.esc_attr($filter_buttons_align).'">';
                        $html .= '<div class="wrap">';
                            $html .= '<button data-filter="*" class="active">'.esc_html__('All', 'imate').'</button>';
                            foreach($category_array as $item) { 
                                $name = $item["name"];
                                $slug = $item["slug"];
                                $html .= '<button data-filter=".category-'.esc_attr($slug).'">'.esc_html($name).'</button>';
                            }
                        $html .= '</div>';
                    $html .= '</div>';
                }
                $html .= '<div class="portfolio-items row portfolio-type-'.$type.' gap-'.$gap.' cols-'.$cols.' hover-'.$hover_effect.' '.$wrap_id.' '.$wrap_classes.'">';
                    if($type != 'carousel') {
                        $html .= '<div class="grid-sizer '.esc_attr($item_col).'"></div>';
                    }
                    while ( $porfolio_array->have_posts() ) : $porfolio_array->the_post();
                        $id = get_the_ID();
                        $item = get_post($id);
                        $item_num++;
                        $name = $item->post_title;
                        $item_class = $category_links_html = $category = "";
                        if(is_array(wp_get_post_terms( $id, 'fw-portfolio-category'))) {
                            for ($i=0; $i < count(wp_get_post_terms( $id, 'fw-portfolio-category')); $i++) { 
                                $category_links_html .= '<a href="'.esc_url(get_category_link(wp_get_post_terms( $id, 'fw-portfolio-category')[$i]->term_id)).'">'.esc_html(wp_get_post_terms( $id, 'fw-portfolio-category')[$i]->name).'</a>, ';
                                $category .= esc_html(wp_get_post_terms( $id, 'fw-portfolio-category')[$i]->name).', ';
                                $item_class .= 'category-'.wp_get_post_terms( $id, 'fw-portfolio-category')[$i]->slug.' ';
                            }
                        }
                        $item_class = trim($item_class, ' ');
                        $category = trim($category, ', ');
                        $category_links_html = trim($category_links_html, ', ');
                        $thumb = get_post_meta( $id, '_thumbnail_id', true );
                        $image = wp_get_attachment_image_src( $thumb , 'large' );

                        if($popup_mode == 'off' || $type == 'carousel') {
                            $link = get_permalink($id);
                        } else {
                            $link = wp_get_attachment_image_src( $thumb , 'full' )[0];
                            $item_class .= ' popup-item';
                        }

                        if($paged > 1) {
                            $num = $item_num+$paged*$count_items-$count_items;
                        } else {
                            $num = $item_num;
                        }

                        if($type == 'carousel' && $show_desc == 'on') {
                            $desc = strip_tags(strip_shortcodes($item->post_content));
                            if(function_exists('iconv_strlen') && iconv_strlen ($desc, 'UTF-8') > 170) {
                                $desc = mb_substr($desc, 0, 170).'...';
                            } else {
                                $desc = mb_substr($desc, 0, 170).'...';
                            }
                        }

                        $item_col_css = $item_col;

                        $html .= '<article class="portfolio-item '.esc_attr($item_class.' '.$item_col).'">';
                            $html .= '<div class="wrap '.esc_attr($animation).'">';
                                if($type == 'grid' || $type == 'packery') {
                                    $html .= '<div class="a-img"><div style="background-image: url('.esc_url($image[0]).');"></div></div>';
                                } else if($type == 'masonry') {
                                    $html .= '<div class="a-img"><img width="'.esc_attr($image[1]).'" height="'.esc_attr($image[2]).'" src="'.esc_url($image[0]).'" alt="'.esc_html($name).'"></div>';
                                }
                                if($show_heading == 'on') {
                                    $html .= '<h6><span class="cell">';
                                        if($show_category == 'on' && !empty($category)) {
                                            $html .= '<span class="categ">'.strip_tags($category).'</span>';
                                        }
                                        $html .= '<span class="name">'.esc_html($name).'</span>';
                                    $html .= '</span></h6>';
                                }
                            $html .= '</div>';
                            $html .= '<a href="'.esc_url($link).'" data-size="'.esc_attr($image[1].'x'.$image[2]).'" data-id="'.esc_attr($num).'"><span></span></a>';
                        $html .= '</article>';
                    endwhile;
                    wp_reset_postdata();
                $html .= '</div>';
            }

            if($type == 'carousel') {
                $html .= '<div class="owl-nav"><div class="container"></div></div>';
            }

            if($navigation == "pagination") {
                if (function_exists('imate_wp_corenavi')) {
                    $html .= imate_wp_corenavi($max_num_pages);
                } else {
                    $html .= wp_link_pages();
                };
            }
            if(is_array($porfolio_array->posts) && $navigation == "load_more" && $max_num_pages > 1) {
                $html .= '<div class="load-button tac"><a href="#" data-wrap=".'.esc_attr($wrap_id).'" data-max="'.esc_attr($max_num_pages).'" data-start-page="'.esc_attr($paged).'" data-next-link="'.esc_url(next_posts($max_num_pages, false)).'" class="button-style2"><span>'.esc_html('Load more', 'imate').'</span></a></div>';
            }
        $html .= '</div>';

        return $html;
         
    }
     
} // End Element Class
 
 
// Element Class Init
new PT_Portfolio_Items();