<?php

// Element Description: PT Tabs

class PT_Tabs extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_tabs_mapping' ) );
        add_shortcode( 'pt_tabs', array( $this, 'pt_tabs_html' ) );
        add_shortcode( 'pt_tabs_item', array( $this, 'pt_tabs_item_html' ) );
    }
     
    // Element Mapping
    public function pt_tabs_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Tabs", "imate"),
            "base" => "pt_tabs",
            "as_parent" => array('only' => 'pt_tabs_item'),
            "content_element" => true,
            "show_settings_on_create" => false,
            "icon" => "shortcode-icon-tabs",
            "is_container" => true,
            "category" => esc_html__("By PT", "imate"),
            "params" => array(
                array(
                    "type" => "animation_style",
                    "heading" => esc_html__( "Animation In", "imate" ),
                    "param_name" => "animation",
                ),
                array(
                    'type' => 'css_editor',
                    'heading' => esc_html__( 'CSS box', 'imate' ),
                    'param_name' => 'css',
                    'group' => esc_html__( 'Design Options', 'imate' ),
                ),
            ),
            "js_view" => 'VcColumnView'
        ) );
        vc_map( array(
            "name" => esc_html__("Tabs item", "imate"),
            "base" => "pt_tabs_item",
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-tabs",
            "is_container" => true,
            "as_child" => array('only' => 'pt_tabs'),
            "params" => array(
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Title", "imate"),
                    "param_name" => "title",
                    "admin_label" => true,
                ),
            ),
            "js_view" => 'VcColumnView'
        ) );
    }
     
     
    // Element HTML
    public function pt_tabs_html( $atts, $content = null ) {
        
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'animation' => '',
                    'css' => ''
                ), 
                $atts
            )
        );

        $block_class = $id = uniqid('tabs-');

        if(!empty($animation)) {
            $block_class .= ' '.$this->getCSSAnimation($animation);
        }

        if(!empty($css)) {
            $block_class .= ' '.vc_shortcode_custom_css_class( $css, ' ' );
        }

        $tabs = array();
        $tabs = pt_the_shortcodes( $tabs, $content );

        wp_enqueue_script( 'imate-script', get_template_directory_uri() . '/js/script.js' );

        wp_add_inline_script('imate-script', "jQuery(document).ready(function(jQuery) {
            jQuery('.".esc_attr($id)."').each(function(){
                jQuery(this).pt_tabs();
            });
        });");

        ob_start();
        ?>

        <div class="tabs <?php echo esc_attr($block_class) ?>">
            <div class="tabs-head">
                <?php foreach ($tabs as $key => $tab) { 
                    extract(
                        shortcode_atts(
                            array(
                                'title' => '',
                            ), 
                            $tab
                        )
                    );
                ?>
                    <div class="item<?php echo ($key == 0) ? ' current': ''; ?>">
                        <span><?php echo strip_tags($title) ?></span>
                    </div>
                <?php } ?>
            </div>
            <div class="tabs-body"><?php echo do_shortcode($content) ?></div>
        </div>
        
        <?php
        return ob_get_clean();
         
    }

    // Element HTML
    public function pt_tabs_item_html( $atts, $content = null ) {

        extract(
            shortcode_atts(
                array(
                    'title' => '',
                ), 
                $atts
            )
        );

        ob_start();
        ?>
            <div class="tab-content">
                <div class="tab-m-button">
                    <span><?php echo strip_tags($title) ?></span>
                </div>
                <div class="tab-inner-content"><?php echo do_shortcode($content) ?></div>
            </div>
        <?php
        return ob_get_clean();
         
    }
     
} // End Element Class
 
 
// Element Class Init
new PT_Tabs();    
if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
    class WPBakeryShortCode_PT_Tabs extends WPBakeryShortCodesContainer {
    }
}
if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
    class WPBakeryShortCode_PT_Tabs_Item extends WPBakeryShortCodesContainer {
    }
}

