<?php

// Element Description: PT Video

class PT_Video extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_video_mapping' ) );
        add_shortcode( 'pt_video', array( $this, 'pt_video_html' ) );
    }
     
    // Element Mapping
    public function pt_video_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Video", "imate"),
            "base" => "pt_video",
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-video",
            "category" => esc_html__("By PT", "imate"),
            "params" => array(
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Style", "imate" ),
                    "param_name"  => "style",
                    "value"      => array(
                        esc_html__( "Style 1", "imate" ) => "style1",
                        esc_html__( "Style 2", "imate" ) => "style2",
                    ),
                ),
                array(
                    "type"        => "textfield",
                    "heading"     => esc_html__( "Video url", "imate" ),
                    "param_name"  => "video_url",
                    "description" => esc_html__('YouTube or Vimeo link', 'imate')
                ),
                array(
                    "type" => "attach_image",
                    "heading" => esc_html__("Video Cover Image", "imate"),
                    "param_name" => "video_cover_image",
                ),
                array(
                    "type"        => "textfield",
                    "heading"     => esc_html__( "Height", "imate" ),
                    "param_name"  => "height",
                    "description" => esc_html__( "Exapmle: 400", "imate" )
                ),
                array(
                    "type" => "animation_style",
                    "heading" => esc_html__( "Animation In", "imate" ),
                    "param_name" => "animation",
                ),
            ),
        ) );
    }
     
     
    // Element HTML
    public function pt_video_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'style' => 'style1',
                    'video_url' => '',
                    'video_cover_image' => '',
                    'animation' => '',
                    'height' => '',
                ), 
                $atts
            )
        );

        $class = $id = uniqid('video-block-');

        $custom_css = $style_attr = $item_attr = $image_attr = '';

        $class .= ' '.$style;

        if(!empty($animation)) {
            $class .= ' '.$this->getCSSAnimation($animation);
        }

        if(!empty($video_cover_image)) {
            $image_attr = $style_attr = 'background-image: url('.esc_url(wp_get_attachment_image_src($video_cover_image, 'full')[0]).');';
        }

        if(!empty($height)) {
            $style_attr .= 'height: '.$height.'px;';
            $class .= ' fix-height';
        }

        if(!empty($custom_css)) {
            wp_enqueue_style('imate-custom-style', get_template_directory_uri() . '/css/custom_script.css');
            wp_add_inline_style( 'imate-custom-style', $custom_css );
        }

        ob_start();
        
        if($video_url) {
            $video_url = VideoUrlParser::get_url_embed($video_url);
        ?>
            <div class="video-block <?php echo esc_attr($class) ?>">
                <?php if($style == 'style1') { ?>
                    <div class="blur-img" style="<?php echo esc_attr($image_attr) ?>"></div>
                <?php } ?>
                <a href="#" data-type="video" class="single-popup-item" style="<?php echo esc_attr($style_attr) ?>" <?php echo $item_attr ?> data-size="960x640" data-video='<div class="wrapper"><div class="video-wrapper"><iframe class="pswp__video" width="960" height="640" src="<?php echo esc_url($video_url) ?>" frameborder="0" allowfullscreen></iframe></div></div>'><div><div class="play-button"><i class="fa fa-play"></i></div></div></a>
            </div>
        <?php }
        return ob_get_clean();
    }

} // End Element Class
 
 
// Element Class Init
new PT_Video();