<?php

// Element Description: PT Work Steps

class PT_Work_Steps extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_work_steps_mapping' ) );
        add_shortcode( 'pt_work_steps', array( $this, 'pt_work_steps_html' ) );
        add_shortcode( 'pt_work_steps_item', array( $this, 'pt_work_steps_item_html' ) );
    }
     
    // Element Mapping
    public function pt_work_steps_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Work Steps", "imate"),
            "base" => "pt_work_steps",
            "as_parent" => array('only' => 'pt_work_steps_item'),
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-work-steps",
            "is_container" => true,
            "category" => esc_html__("By PT", "imate"),
            "params" => array(
                array(
                    'type' => 'colorpicker',
                    'heading' => esc_html__( 'Step num color', 'imate' ),
                    'param_name' => 'step_color',
                ),
                array(
                    'type' => 'colorpicker',
                    'heading' => esc_html__( 'Dotted line color', 'imate' ),
                    'param_name' => 'line_color',
                ),
                array(
                    'type' => 'colorpicker',
                    'heading' => esc_html__( 'Heading color', 'imate' ),
                    'param_name' => 'heading_color',
                ),
                array(
                    'type' => 'colorpicker',
                    'heading' => esc_html__( 'Text color', 'imate' ),
                    'param_name' => 'text_color',
                ),
                array(
                    'type' => 'colorpicker',
                    'heading' => esc_html__( 'Link color', 'imate' ),
                    'param_name' => 'link_color',
                ),
                array(
                    'type' => 'css_editor',
                    'heading' => esc_html__( 'CSS box', 'imate' ),
                    'param_name' => 'css',
                    'group' => esc_html__( 'Design Options', 'imate' ),
                ),
                array(
                    "type" => "animation_style",
                    "heading" => esc_html__( "Animation In", "imate" ),
                    "param_name" => "animation",
                ),
            ),
            "js_view" => 'VcColumnView'
        ) );
        vc_map( array(
            "name" => esc_html__("Work Step item", "imate"),
            "base" => "pt_work_steps_item",
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-work-steps",
            "as_child" => array('only' => 'pt_work_steps'),
            "params" => array(
                array(
                    "type" => "number",
                    "heading" => esc_html__("Step Num", "imate"),
                    "param_name" => "step_num",
                ),
                array(
                    "type" => "textarea",
                    "heading" => esc_html__("Heading", "imate"),
                    "param_name" => "heading",
                    "admin_label" => true,
                ),
                array(
                    "type" => "textarea",
                    "heading" => esc_html__("Text", "imate"),
                    "param_name" => "text",
                ),
                array(
                    "type" => "vc_link",
                    "heading" => esc_html__("Link", "imate"),
                    "param_name" => "link",
                ),
            )
        ) );
    }
     
     
    // Element HTML
    public function pt_work_steps_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'step_color' => '',
                    'line_color' => '',
                    'heading_color' => '',
                    'text_color' => '',
                    'link_color' => '',
                    'css' => '',
                    'animation' => ''
                ), 
                $atts
            )
        );

        $item_class = $id = uniqid('work-steps-');

        if(!empty($css)) {
            $item_class .= ' '.vc_shortcode_custom_css_class( $css, ' ' );
        }

        if(!empty($animation)) {
            $item_class .= ' '.$this->getCSSAnimation($animation);
        }

        $html = "";

        // Fill $html var with data
        $custom_css = "";

        if(!empty($step_color)) {
            $custom_css .= '.'.$id.' .num {
                color: '.$step_color.';
            }';
        }

        if(!empty($line_color)) {
            $custom_css .= '.'.$id.' .num .decor:after {
                color: '.$line_color.' !important;
            }';
        }

        if(!empty($heading_color)) {
            $custom_css .= '.'.$id.' .h {
                color: '.$heading_color.';
            }';
        }

        if(!empty($text_color)) {
            $custom_css .= '.'.$id.' .text {
                color: '.$text_color.';
            }';
        }

        if(!empty($link_color)) {
            $custom_css .= '.'.$id.' .link {
                color: '.$link_color.';
            }';
        }

        if(!empty($custom_css)) {
            wp_enqueue_style('imate-custom-style', get_template_directory_uri() . '/css/custom_script.css');
            wp_add_inline_style( 'imate-custom-style', $custom_css );
        }

        ob_start();
        ?>
        <div class="work-steps clearfix <?php echo esc_attr($item_class) ?>">
            <?php echo do_shortcode($content) ?>
        </div>
         
        <?php
        return ob_get_clean();
         
    }

    // Element HTML
    public function pt_work_steps_item_html( $atts ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'step_num' => '',
                    'heading' => '',
                    'text' => '',
                    'link' => '',
                ), 
                $atts
            )
        );

        ob_start();
        ?>

        <div class="work-step-item">
            <div class="wrap">
                <?php if(!empty($step_num)) { ?>
                    <div class="num">
                        <div class="decor"></div>
                        <?php echo strip_tags($step_num) ?>
                    </div>
                <?php } if(!empty($heading)) { ?>
                    <h6 class="h"><?php echo wp_kses_post($heading) ?></h6>
                <?php } if(!empty($text)) { ?>
                    <div class="text"><?php echo wp_kses_post($text) ?></div>
                <?php } if(isset(vc_build_link($link)['url']) && !empty(vc_build_link($link)['url'])) { 
                    $link = vc_build_link($link);
                    
                    if(empty($link['target'])) {
                        $link['target'] = '_self';
                    }
                    if(empty($link['title'])) {
                        $link['title'] = esc_html__('read more', 'imate');
                    }
                ?>
                    <a href="<?php echo esc_url($link['url']) ?>" target="<?php echo esc_attr($link['target']) ?>" class="link"><span><?php echo strip_tags($link['title']) ?></span><i class="fa fa-angle-right"></i></a>
                <?php } ?>
            </div>
        </div>
        
        <?php
        return ob_get_clean();
         
    }
     
} // End Element Class
 
 
// Element Class Init
new PT_Work_Steps();    
if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
    class WPBakeryShortCode_PT_Work_Steps extends WPBakeryShortCodesContainer {
    }
}
if ( class_exists( 'WPBakeryShortCode' ) ) {
    class WPBakeryShortCode_PT_Work_Steps_Item extends WPBakeryShortCode {
    }
}

