<?php

// Element Description: PT Accordion

class PT_Accordion extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_accordion_mapping' ) );
        add_shortcode( 'pt_accordion', array( $this, 'pt_accordion_html' ) );
        add_shortcode( 'pt_accordion_item', array( $this, 'pt_accordion_item_html' ) );
    }
     
    // Element Mapping
    public function pt_accordion_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Accordion", "imate"),
            "base" => "pt_accordion",
            "as_parent" => array('only' => 'pt_accordion_item'),
            "content_element" => true,
            "show_settings_on_create" => false,
            "icon" => "shortcode-icon-accordion",
            "is_container" => true,
            "category" => esc_html__("By PT", "imate"),
            "params" => array(
                array(
                    "type"        => "el_id",
                    "heading"     => esc_html__( "Uniq ID", "imate" ),
                    "param_name"  => "uniq_id",
                    "value"       => uniqid(),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Style", "imate" ),
                    "param_name"  => "style",
                    "value"      => array(
                        esc_html__( "Style 1", "imate" ) => "style1",
                        esc_html__( "Style 2", "imate" ) => "style2",
                    ),
                ),
                array(
                    "type" => "animation_style",
                    "heading" => esc_html__( "Animation In", "imate" ),
                    "param_name" => "animation",
                ),
                array(
                    'type' => 'css_editor',
                    'heading' => esc_html__( 'CSS box', 'imate' ),
                    'param_name' => 'css',
                    'group' => esc_html__( 'Design Options', 'imate' ),
                ),
            ),
            "js_view" => 'VcColumnView'
        ) );
        vc_map( array(
            "name" => esc_html__("Accordion item", "imate"),
            "base" => "pt_accordion_item",
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-accordion",
            "as_child" => array('only' => 'pt_accordion'),
            "params" => array(
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Opened", "imate" ),
                    "param_name"  => "open",
                    "value"       => "off",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "imate" ),
                            "off"   => esc_html__( "Off", "imate" ),
                        ),
                    ),
                    "default_set" => false,
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Label", "imate"),
                    "param_name" => "name",
                    "admin_label" => true,
                ),
                array(
                    "type" => "textarea",
                    "heading" => esc_html__("Text", "imate"),
                    "param_name" => "text",
                ),
            )
        ) );
    }
     
     
    // Element HTML
    public function pt_accordion_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                    'style' => 'style1',
                    'animation' => '',
                    'css' => ''
                ), 
                $atts
            )
        );

        $item_class = $id = 'accordion-'.$uniq_id;

        if($style != 'style1') {
            $item_class .= ' '.$style;
        }

        if(!empty($animation)) {
            $item_class .= ' '.$this->getCSSAnimation($animation);
        }

        if(!empty($css)) {
            $item_class .= ' '.vc_shortcode_custom_css_class( $css, ' ' );
        }

        $html = '<div class="accordion-items '.esc_attr($item_class).'">';
            $html .= do_shortcode($content);
        $html .= '</div>';
         
        return $html;
         
    }

    // Element HTML
    public function pt_accordion_item_html( $atts ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'open' => 'off',
                    'name' => '',
                    'text' => '',
                ), 
                $atts
            )
        );
        
        // Fill $html var with data

        $html = $item_class = $text_attr = "";

        if($open == 'on') {
            $item_class = ' active';
            $text_attr = 'display: block;';
        }

        if(!empty($name) && !empty($text)) {
            $html = '<div class="accordion-item'.esc_attr($item_class).'">';
                $html .= '<div class="label"><div class="cell">'.wp_kses_post($name).'</div><span></span></div>';
                $html .= '<div class="text" style="'.esc_attr($text_attr).'">'.wp_kses_post($text).'</div>';
            $html .= '</div>';
        }

        return $html;
         
    }
     
} // End Element Class
 
 
// Element Class Init
new PT_Accordion();    
if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
    class WPBakeryShortCode_PT_Accordion extends WPBakeryShortCodesContainer {
    }
}
if ( class_exists( 'WPBakeryShortCode' ) ) {
    class WPBakeryShortCode_PT_Accordion_Item extends WPBakeryShortCode {
    }
}

