<?php

// Element Description: PT Brand Logos

class PT_Brand_Logos extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_brand_logos_mapping' ) );
        add_shortcode( 'pt_brand_logos', array( $this, 'pt_brand_logos_html' ) );
        add_shortcode( 'pt_brand_logos_item', array( $this, 'pt_brand_logos_item_html' ) );
    }
     
    // Element Mapping
    public function pt_brand_logos_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Brand Logos", "imate"),
            "base" => "pt_brand_logos",
            "as_parent" => array('only' => 'pt_brand_logos_item'),
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-brand",
            "is_container" => true,
            "category" => esc_html__("By PT", "imate"),
            "params" => array(
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Desktop", "imate" ),
                    "param_name"  => "desktop_cols",
                    "value"      => array(
                        esc_html__( "Col 1", "imate" ) => "1",
                        esc_html__( "Col 2", "imate" ) => "2",
                        esc_html__( "Col 3", "imate" ) => "3",
                        esc_html__( "Col 4", "imate" ) => "4",
                        esc_html__( "Col 5", "imate" ) => "5",
                    ),
                    "std" => '3',
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Tablet", "imate" ),
                    "param_name"  => "tablet_cols",
                    "value"      => array(
                        esc_html__( "Col 1", "imate" ) => "1",
                        esc_html__( "Col 2", "imate" ) => "2",
                        esc_html__( "Col 3", "imate" ) => "3",
                        esc_html__( "Col 4", "imate" ) => "4",
                        esc_html__( "Col 5", "imate" ) => "5",
                    ),
                    "std" => '2',
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Mobile", "imate" ),
                    "param_name"  => "mobile_cols",
                    "value"      => array(
                        esc_html__( "Col 1", "imate" ) => "1",
                        esc_html__( "Col 2", "imate" ) => "2",
                        esc_html__( "Col 3", "imate" ) => "3",
                        esc_html__( "Col 4", "imate" ) => "4",
                        esc_html__( "Col 5", "imate" ) => "5",
                    ),
                    "std" => '1',
                ),
                array(
                    "type" => "animation_style",
                    "heading" => esc_html__( "Animation In", "imate" ),
                    "param_name" => "animation",
                ),
            ),
            "js_view" => 'VcColumnView'
        ) );
        vc_map( array(
            "name" => esc_html__("Brand Logos item", "imate"),
            "base" => "pt_brand_logos_item",
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-brand",
            "as_child" => array('only' => 'pt_brand_logos'),
            "is_container" => true,
            "params" => array(
                array(
                    "type" => "attach_image",
                    "heading" => esc_html__("Logo", "imate"),
                    "param_name" => "logo",
                ),
                array(
                    "type" => "vc_link",
                    "heading" => esc_html__("Link", "imate"),
                    "param_name" => "link",
                    "admin_label" => true,
                ),
            ),
        ) );
    }
     
     
    // Element HTML
    public function pt_brand_logos_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'desktop_cols' => '3',
                    'tablet_cols' => '2',
                    'mobile_cols' => '1',
                    'animation' => ''
                ), 
                $atts
            )
        );

        $items_class = $id = uniqid('brand-logo-items-');

        if(!empty($animation)) {
            $items_class .= ' '.$this->getCSSAnimation($animation);
        }

        wp_enqueue_style( 'owl-carousel-css', get_template_directory_uri() . '/css/owl.carousel.css');
        wp_enqueue_script( 'owl-carousel-js', get_template_directory_uri() . '/js/owl.carousel.min.js', array('jquery'), true );
        wp_enqueue_script( 'imate-script', get_template_directory_uri() . '/js/script.js' );

        wp_add_inline_script('imate-script', "jQuery(document).ready(function(jQuery) {
            jQuery('.".esc_attr($id)."').each(function(){
                var head_slider = jQuery(this);
                if(jQuery(this).find('.brand-logo-item').length > 1){
                    head_slider.addClass('owl-carousel').owlCarousel({
                        loop:true,
                        items:1,
                        nav: true,
                        dots: false,
                        autoplay: false,
                        navClass: ['owl-prev material-design-icon-keyboard-left-arrow-button','owl-next material-design-icon-keyboard-right-arrow-button'],
                        navText: false,
                        margin: 30,
                        responsive:{
                            0:{
                                nav: false,
                                items: 1
                            },
                            768:{
                                nav: true,
                                items: ".esc_js($mobile_cols)."
                            },
                            992:{
                                items: ".esc_js($tablet_cols)."
                            },
                            1200:{
                                items: ".esc_js($desktop_cols)."
                            },
                        },
                    });
                }
            });
        });");

        ob_start();
        ?>

        <div class="brand-logo-items <?php echo esc_attr($items_class) ?>">
            <?php echo do_shortcode($content) ?>
        </div>

        <?php
        return ob_get_clean();
         
    }

    // Element HTML
    public function pt_brand_logos_item_html( $atts, $content = null ) {

        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'logo' => '',
                    'link' => '',
                ), 
                $atts
            )
        );
        
        // Fill $html var with data

        $html = $logo_img = "";

        if(isset(wp_get_attachment_image_src($logo, 'large')[0])) {
            $logo_img = wp_get_attachment_image($logo, 'full');
        }

        if(isset(vc_build_link($link)['url']) && !empty(vc_build_link($link)['url'])) {
            $link = vc_build_link($link);
            if(empty($link['target'])) {
                $link['target'] = '_self';
            }
        } else {
            $link = '';
        }

        ob_start();

        if(!empty($logo_img)) { ?>

            <div class="brand-logo-item">
                <div>
                    <?php if(!empty($link)) { ?>
                        <a href="<?php echo esc_url($link['url']) ?>" target="<?php echo esc_attr($link['target']) ?>">
                    <?php }
                    echo $logo_img;
                    if(!empty($link)) { ?>
                        </a>
                    <?php } ?>
                </div>
            </div>
            
        <?php }

        return ob_get_clean();
         
    }
     
} // End Element Class
 
 
// Element Class Init
new PT_Brand_Logos();    
if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
    class WPBakeryShortCode_PT_Brand_Logos extends WPBakeryShortCodesContainer {
    }
}
if ( class_exists( 'WPBakeryShortCode' ) ) {
    class WPBakeryShortCode_PT_Brand_Logos_Item extends WPBakeryShortCode {
    }
}

