<?php

// Element Description: PT Contact Row

class PT_Contact_Row extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_contact_row_mapping' ) );
        add_shortcode( 'pt_contact_row', array( $this, 'pt_contact_row_html' ) );
    }
     
    // Element Mapping
    public function pt_contact_row_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Contact Row", "imate"),
            "base" => "pt_contact_row",
            "as_parent" => array('only' => 'pt_contact_row_item'),
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-contact-row",
            "category" => esc_html__("By PT", "imate"),
            "params" => array(
                array(
                    'type' => 'dropdown',
                    'heading' => esc_html__( 'Icon library', 'imate' ),
                    'value' => array(
                        esc_html__( 'Font Awesome', 'imate' ) => 'fontawesome',
                        esc_html__( 'Open Iconic', 'imate' ) => 'openiconic',
                        esc_html__( 'Typicons', 'imate' ) => 'typicons',
                        esc_html__( 'Entypo', 'imate' ) => 'entypo',
                        esc_html__( 'Linecons', 'imate' ) => 'linecons',
                        esc_html__( 'Mono Social', 'imate' ) => 'monosocial',
                        esc_html__( 'Material', 'imate' ) => 'material',
                    ),
                    'admin_label' => true,
                    'param_name' => 'type',
                    'description' => esc_html__( 'Select icon library.', 'imate' ),
                ),
                array(
                    'type' => 'iconpicker',
                    'heading' => esc_html__( 'Icon', 'imate' ),
                    'param_name' => 'icon_fontawesome',
                    'value' => 'fa fa-adjust',
                    'settings' => array(
                        'emptyIcon' => false,
                        'iconsPerPage' => 4000,
                    ),
                    'dependency' => array(
                        'element' => 'type',
                        'value' => 'fontawesome',
                    ),
                    'description' => esc_html__( 'Select icon from library.', 'imate' ),
                ),
                array(
                    'type' => 'iconpicker',
                    'heading' => esc_html__( 'Icon', 'imate' ),
                    'param_name' => 'icon_openiconic',
                    'value' => 'vc-oi vc-oi-dial',
                    'settings' => array(
                        'emptyIcon' => false,
                        'type' => 'openiconic',
                        'iconsPerPage' => 4000,
                    ),
                    'dependency' => array(
                        'element' => 'type',
                        'value' => 'openiconic',
                    ),
                    'description' => esc_html__( 'Select icon from library.', 'imate' ),
                ),
                array(
                    'type' => 'iconpicker',
                    'heading' => esc_html__( 'Icon', 'imate' ),
                    'param_name' => 'icon_typicons',
                    'value' => 'typcn typcn-adjust-brightness',
                    'settings' => array(
                        'emptyIcon' => false,
                        'type' => 'typicons',
                        'iconsPerPage' => 4000,
                    ),
                    'dependency' => array(
                        'element' => 'type',
                        'value' => 'typicons',
                    ),
                    'description' => esc_html__( 'Select icon from library.', 'imate' ),
                ),
                array(
                    'type' => 'iconpicker',
                    'heading' => esc_html__( 'Icon', 'imate' ),
                    'param_name' => 'icon_entypo',
                    'value' => 'entypo-icon entypo-icon-note',
                    'settings' => array(
                        'emptyIcon' => false,
                        'type' => 'entypo',
                        'iconsPerPage' => 4000,
                    ),
                    'dependency' => array(
                        'element' => 'type',
                        'value' => 'entypo',
                    ),
                ),
                array(
                    'type' => 'iconpicker',
                    'heading' => esc_html__( 'Icon', 'imate' ),
                    'param_name' => 'icon_linecons',
                    'value' => 'vc_li vc_li-heart',
                    'settings' => array(
                        'emptyIcon' => false,
                        'type' => 'linecons',
                        'iconsPerPage' => 4000,
                    ),
                    'dependency' => array(
                        'element' => 'type',
                        'value' => 'linecons',
                    ),
                    'description' => esc_html__( 'Select icon from library.', 'imate' ),
                ),
                array(
                    'type' => 'iconpicker',
                    'heading' => esc_html__( 'Icon', 'imate' ),
                    'param_name' => 'icon_monosocial',
                    'value' => 'vc-mono vc-mono-fivehundredpx',
                    'settings' => array(
                        'emptyIcon' => false,
                        'type' => 'monosocial',
                        'iconsPerPage' => 4000,
                    ),
                    'dependency' => array(
                        'element' => 'type',
                        'value' => 'monosocial',
                    ),
                    'description' => esc_html__( 'Select icon from library.', 'imate' ),
                ),
                array(
                    'type' => 'iconpicker',
                    'heading' => esc_html__( 'Icon', 'imate' ),
                    'param_name' => 'icon_material',
                    'value' => 'vc-material vc-material-cake',
                    'settings' => array(
                        'emptyIcon' => false,
                        'type' => 'material',
                        'iconsPerPage' => 4000,
                    ),
                    'dependency' => array(
                        'element' => 'type',
                        'value' => 'material',
                    ),
                    'description' => esc_html__( 'Select icon from library.', 'imate' ),
                ),
                array(
                    "type"        => "textarea",
                    "heading"     => esc_html__( "Heading", "imate" ),
                    "param_name"  => "heading",
                    "description" => esc_html__( "Example: {support}@promo-theme.com", "imate"),
                    "admin_label" => true,
                ),
                array(
                    "type"        => "textarea",
                    "heading"     => esc_html__( "Description", "imate" ),
                    "param_name"  => "desc",
                ),
                array(
                    "type" => "animation_style",
                    "heading" => esc_html__( "Animation In", "imate" ),
                    "param_name" => "animation",
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Icon Size", "imate"),
                    "param_name" => "icon_size",
                    "group" => esc_html__("Customize", "imate")
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Icon Color", "imate"),
                    "param_name" => "icon_color_hex",
                    "group" => esc_html__("Customize", "imate")
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Heading Size", "imate"),
                    "param_name" => "heading_size",
                    "group" => esc_html__("Customize", "imate")
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Heading Color", "imate"),
                    "param_name" => "heading_color_hex",
                    "group" => esc_html__("Customize", "imate")
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Heading Decor Color", "imate"),
                    "param_name" => "heading_decor_color_hex",
                    "group" => esc_html__("Customize", "imate")
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Text Size", "imate"),
                    "param_name" => "text_size",
                    "group" => esc_html__("Customize", "imate")
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Text Color", "imate"),
                    "param_name" => "text_color_hex",
                    "group" => esc_html__("Customize", "imate")
                ),
                array(
                    'type' => 'css_editor',
                    'heading' => esc_html__( 'CSS box', 'imate' ),
                    'param_name' => 'css',
                    'group' => esc_html__( 'Design Options', 'imate' ),
                ),
            ),
        ) );
    }
     
     
    // Element HTML
    public function pt_contact_row_html( $atts ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                    'type' => 'fontawesome',
                    'icon_fontawesome' => 'fa fa-adjust',
                    'icon_openiconic' => 'vc-oi vc-oi-dial',
                    'icon_typicons' => 'typcn typcn-adjust-brightness',
                    'icon_entypo' => 'entypo-icon entypo-icon-note',
                    'icon_linecons' => 'vc_li vc_li-heart',
                    'icon_monosocial' => 'vc-mono vc-mono-fivehundredpx',
                    'icon_material' => 'vc-material vc-material-cake',
                    'desc' => '',
                    'heading' => '',
                    'animation' => '',
                    'icon_color_hex' => '',
                    'text_color_hex' => '',
                    'heading_color_hex' => '',
                    'heading_decor_color_hex' => '',
                    'icon_size' => '',
                    'heading_size' => '',
                    'text_size' => '',
                    'css' => '',
                ), 
                $atts
            )
        );

        if(empty($uniq_id)) {
            $uniq_id = uniqid();
        }

        $item_css = $item_id = 'contact-row-'.$uniq_id;

        $custom_css = '';

        if(isset($icon_color_hex) && !empty($icon_color_hex)) {
            $custom_css .= '.'.$item_id.' .icon {
                color: '.$icon_color_hex.';
            }';
        }

        if(isset($text_color_hex) && !empty($text_color_hex)) {
            $custom_css .= '.'.$item_id.' .desc {
                color: '.$text_color_hex.';
            }';
        }

        if(isset($heading_color_hex) && !empty($heading_color_hex)) {
            $custom_css .= '.'.$item_id.' .heading {
                color: '.$heading_color_hex.';
            }';
        }

        if(isset($heading_decor_color_hex) && !empty($heading_decor_color_hex)) {
            $custom_css .= '.'.$item_id.' .heading span {
                color: '.$heading_decor_color_hex.';
            }';
        }

        if(isset($icon_size) && !empty($icon_size)) {
            $custom_css .= '.'.$item_id.' .icon {
                font-size: '.$icon_size.';
            }';
        }

        if(isset($heading_size) && !empty($heading_size)) {
            $custom_css .= '.'.$item_id.' .heading {
                font-size: '.$heading_size.';
            }';
        }

        if(isset($text_size) && !empty($text_size)) {
            $custom_css .= '.'.$item_id.' .desc {
                font-size: '.$text_size.';
            }';
        }

        if(!empty($custom_css)) {
            wp_enqueue_style('imate-custom-style', get_template_directory_uri() . '/css/custom_script.css');
            wp_add_inline_style( 'imate-custom-style', $custom_css );
        }

        $icon = 'icon_'.$type;

        if(!empty($animation)) {
            $item_css .= ' '.$this->getCSSAnimation($animation);
        }

        if(!empty($css)) {
            $item_css .= ' '.vc_shortcode_custom_css_class( $css, ' ' );
        }

        ob_start();
        ?>

        <div class="contact-row <?php echo esc_attr($item_css) ?>">
            <?php if(isset($$icon) && !empty($$icon)) { ?>
                <div class="icon <?php echo esc_attr($$icon) ?>"></div>
            <?php } if(!empty($heading)) {
                $heading = str_replace(array('{', '}'), array('<span>', '</span>'), $heading);
            ?>
                <h5 class="heading"><?php echo wp_kses_post($heading) ?></h5>
            <?php } if(!empty($desc)) { ?>
                <div class="desc"><?php echo wp_kses_post($desc) ?></div>
            <?php } ?>
        </div>
        
        <?php
        return ob_get_clean();
         
    }
     
} // End Element Class
 
 
// Element Class Init
new PT_Contact_Row();    
if ( class_exists( 'WPBakeryShortCode' ) ) {
    class WPBakeryShortCode_PT_Contact_Row extends WPBakeryShortCode {
    }
}
