<?php

// Element Description: PT Num Box

class PT_Num_Box extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_num_box_mapping' ) );
        add_shortcode( 'pt_num_box', array( $this, 'pt_num_box_html' ) );
        add_shortcode( 'pt_num_box_item', array( $this, 'pt_num_box_item_html' ) );
    }
     
    // Element Mapping
    public function pt_num_box_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Num Box", "imate"),
            "base" => "pt_num_box",
            "as_parent" => array('only' => 'pt_num_box_item'),
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-num-box",
            "is_container" => true,
            "category" => esc_html__("By PT", "imate"),
            "params" => array(
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Align", "imate" ),
                    "param_name"  => "align",
                    "value"      => array(
                        esc_html__( "Left", "imate" ) => "tal",
                        esc_html__( "Center", "imate" ) => "tac",
                        esc_html__( "Right", "imate" ) => "tar",
                    ),
                    "std" => 'tac',
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__( "Num Color", "imate" ),
                    "param_name" => "num_color",
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__( "Heading Color", "imate" ),
                    "param_name" => "heading_color",
                ),
                array(
                    'type' => 'css_editor',
                    'heading' => esc_html__( 'CSS box', 'imate' ),
                    'param_name' => 'css',
                    'group' => esc_html__( 'Design Options', 'imate' ),
                ),
                array(
                    "type" => "animation_style",
                    "heading" => esc_html__( "Animation In", "imate" ),
                    "param_name" => "animation",
                ),
            ),
            "js_view" => 'VcColumnView'
        ) );
        vc_map( array(
            "name" => esc_html__("Num Box item", "imate"),
            "base" => "pt_num_box_item",
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-num-box",
            "as_child" => array('only' => 'pt_num_box'),
            "params" => array(
                array(
                    "type" => "number",
                    "heading" => esc_html__("Num", "imate"),
                    "param_name" => "num",
                    "admin_label" => true,
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Text Before num", "imate"),
                    "param_name" => "before",
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Text After num", "imate"),
                    "param_name" => "after",
                ),
                array(
                    "type" => "textarea",
                    "heading" => esc_html__("Heading", "imate"),
                    "param_name" => "heading",
                    "admin_label" => true,
                ),
            )
        ) );
    }
     
     
    // Element HTML
    public function pt_num_box_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                    'align' => 'tac',
                    'num_color' => '',
                    'heading_color' => '',
                    'css' => '',
                    'animation' => ''
                ), 
                $atts
            )
        );

        $item_class = $id = uniqid('num-box-');

        $item_class .= ' '.$align;

        if(!empty($css)) {
            $item_class .= ' '.vc_shortcode_custom_css_class( $css, ' ' );
        }

        if(!empty($animation)) {
            $item_class .= ' '.$this->getCSSAnimation($animation);
        }

        $html = "";

        // Fill $html var with data
        $custom_css = "";

        if(!empty($num_color)) {
            $custom_css .= '.'.$id.' .num-box-item .num-wrap {
                color: '.$num_color.';
            }';
        }

        if(!empty($heading_color)) {
            $custom_css .= '.'.$id.' .num-box-item .h {
                color: '.$heading_color.';
            }';
        }

        if(!empty($custom_css)) {
            wp_enqueue_style( 'imate-custom-style', get_template_directory_uri() . '/css/custom_script.css' );
            wp_add_inline_style( 'imate-custom-style', $custom_css );
        }

        ob_start();
        ?>

        <div class="num-box <?php echo esc_attr($item_class) ?>">
            <?php echo do_shortcode($content) ?>
        </div>
         
        <?php
        return ob_get_clean();
         
    }

    // Element HTML
    public function pt_num_box_item_html( $atts ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'num' => '',
                    'before' => '',
                    'after' => '',
                    'heading' => '',
                ), 
                $atts
            )
        );

        ob_start();
        
        if(!empty($num)) { ?>
            <div class="num-box-item">
                <div class="num-wrap">
                    <?php if(!empty($before)) { ?>
                        <div class="before"><?php echo strip_tags($before) ?></div>
                    <?php } ?>
                    <div class="num"><?php echo strip_tags($num) ?></div>
                    <?php if(!empty($after)) { ?>
                        <div class="after"><?php echo strip_tags($after) ?></div>
                    <?php } ?>
                </div>
                <?php if(!empty($heading)) { ?>
                    <div class="h"><?php echo wp_kses_post($heading) ?></div>
                <?php } ?>
            </div>

        <?php }

        return ob_get_clean();
         
    }
     
} // End Element Class
 
 
// Element Class Init
new PT_Num_Box();    
if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
    class WPBakeryShortCode_PT_Num_Box extends WPBakeryShortCodesContainer {
    }
}
if ( class_exists( 'WPBakeryShortCode' ) ) {
    class WPBakeryShortCode_PT_Num_Box_Item extends WPBakeryShortCode {
    }
}

