<?php

// Element Description: PT Portfolio Slider With Filter

class PT_Portfolio_Slider_Filter extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_portfolio_slider_with_filter_mapping' ) );
        add_shortcode( 'pt_portfolio_slider_with_filter', array( $this, 'pt_portfolio_slider_with_filter_html' ) );
    }
     
    // Element Mapping
    public function pt_portfolio_slider_with_filter_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Portfolio Slider With Filter", "imate"),
            "base" => "pt_portfolio_slider_with_filter",
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-portfolio-slider-w-filter",
            "is_container" => true,
            "category" => esc_html__("By PT", "imate"),
            "params" => array(
                array(
                    "type"        => "number",
                    "heading"     => esc_html__( "Count items", "imate" ),
                    "param_name"  => "count_items",
                    "value"       => '9',
                    "admin_label" => true,
                    "description" => esc_html__( "Enter -1 to remove the number limit"),
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Filter buttons", "imate" ),
                    "param_name"  => "filter_buttons",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "imate" ),
                            "off"   => esc_html__( "Off", "imate" ),
                        ),
                    ),
                    "default_set" => true,
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Popup mode", "imate" ),
                    "param_name"  => "popup_mode",
                    "value"       => "on",
                    "admin_label" => true,
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "imate" ),
                            "off"   => esc_html__( "Off", "imate" ),
                        ),
                    ),
                    "default_set" => true,
                ),
                 array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Navigation arrows", "imate" ),
                    "param_name"  => "arrows",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__("On", "imate"),
                            "off"   => esc_html__("Off", "imate"),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__("Carousel settings", "imate"),
                ),
                array(
                    "type"        => "number",
                    "heading"     => esc_html__( "Transition speed", "imate" ),
                    "param_name"  => "speed",
                    "value"       => "300",
                    "min"         => "100",
                    "max"         => "10000",
                    "step"        => "100",
                    "suffix"      => "ms",
                    "description" => esc_html__( "Speed at which next slide comes.", "imate" ),
                    "group"       => esc_html__("Carousel settings", "imate"),
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Autoplay Slides", "imate" ),
                    "param_name"  => "autoplay",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "label" => esc_html__( "Enable Autoplay", "imate" ),
                            "on"    => esc_html__("On", "imate"),
                            "off"   => esc_html__("Off", "imate"),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__("Carousel settings", "imate"),
                ),
                array(
                    "type"       => "number",
                    "heading"    => esc_html__( "Autoplay Speed", "imate" ),
                    "param_name" => "autoplay_speed",
                    "value"      => "5000",
                    "min"        => "100",
                    "max"        => "10000",
                    "step"       => "10",
                    "suffix"     => "ms",
                    "dependency" => Array( "element" => "autoplay", "value" => array( "on" ) ),
                    "group"      => esc_html__("Carousel settings", "imate"),
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Heading", "imate" ),
                    "param_name"  => "show_heading",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "imate" ),
                            "off"   => esc_html__( "Off", "imate" ),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__( "Fields", "imate" ),
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Read More", "imate" ),
                    "param_name"  => "show_readmore",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__( "On", "imate" ),
                            "off"   => esc_html__( "Off", "imate" ),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__( "Fields", "imate" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Order by", "imate" ),
                    "param_name"  => "orderby",
                    "value"      => array(
                        esc_html__('Default', 'image') => 'post__in',
                        esc_html__('Author', 'image') => 'author',
                        esc_html__('Date', 'image') => 'date',
                        esc_html__('ID', 'image') => 'ID',
                        esc_html__('Title', 'image') => 'title',
                    ),
                    "group"       => esc_html__( "Sorting", "imate" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Order", "imate" ),
                    "param_name"  => "order",
                    "value"      => array(
                        esc_html__('Ascending order', 'image') => 'ASC',
                        esc_html__('Descending order', 'image') => 'DESC',
                    ),
                    "group"       => esc_html__( "Sorting", "imate" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Source", "imate" ),
                    "param_name"  => "source",
                    "value"      => array(
                        esc_html__( "---", "imate" ) => "",
                        esc_html__( "Items", "imate" ) => "items",
                        esc_html__( "Categories", "imate" ) => "categories",
                    ),
                    "group"       => esc_html__( "Source", "imate" ),
                ),
                array(
                    "type"        => "dropdown_multi",
                    "heading"     => esc_html__( "Items", "imate" ),
                    "param_name"  => "items",
                    "dependency"  => Array( "element" => "source", "value" => array( "items" ) ),
                    "value"       => get_all_portfolio_items(),
                    "group"       => esc_html__( "Source", "imate" ),
                ),
                array(
                    "type"        => "dropdown_multi",
                    "heading"     => esc_html__( "Category", "imate" ),
                    "param_name"  => "categories",
                    "dependency"  => Array( "element" => "source", "value" => array( "categories" ) ),
                    "value"       => get_all_portfolio_category(),
                    "group"       => esc_html__( "Source", "imate" ),
                ),
                array(
                    "type" => "animation_style",
                    "heading" => esc_html__( "Animation In", "imate" ),
                    "param_name" => "animation",
                ),
            ),
        ) );
    }
     
     
    // Element HTML
    public function pt_portfolio_slider_with_filter_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                    'count_items' => '9', 
                    'popup_mode' => 'on',
                    'filter_buttons' => 'on',
                    'filter_buttons_align' => 'tac',
                    'show_heading' => 'on',
                    'show_readmore' => 'on',
                    'orderby' => 'post__in',
                    'order' => 'ASC',
                    'source' => '',
                    'items' => '',
                    'categories' => '',
                    'animation' => '',
                    'arrows' => 'on',
                    'speed' => '300',
                    'autoplay' => 'on',
                    'autoplay_speed' => '5000',
                ), 
                $atts
            )
        );

        $animation = $this->getCSSAnimation($animation);

        $wrap_id = 'portfolio-'.$uniq_id;

        if(is_front_page()) {
            $paged = (get_query_var('page')) ? get_query_var('page') : 1;
        } else {
            $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
        }

        $tax_query = array();

        if ( !empty($categories) && $categories != '0' ) {
            $tax_query = array(
                array(
                    'taxonomy' => 'fw-portfolio-category',
                    'field'    => 'id',
                    'terms'    => $categories
                )
            );
        }
        if($items) {
            $items = explode(',', $items);
        } else {
            $items = '';
        }
        $args = array(
            'post__in'        => $items,
            'posts_per_page'  => $count_items,
            'paged'           => $paged,
            'orderby'         => $orderby,
            'order'           => $order,
            'post_type'       => 'fw-portfolio',
            'post_status'     => 'publish',
            'tax_query'       => $tax_query
        );

        $porfolio_array = new WP_Query( $args );

        $item_num = $max_num_pages = 0;
        $max_num_pages = $porfolio_array->max_num_pages;

        $html = $wrap_classes = $custom_css = "";

        $category_array = array();
        $i = 0;
        while ( $porfolio_array->have_posts() ) : $porfolio_array->the_post();
            $id = get_the_ID();
            $category_array[$i] = array();
            foreach (wp_get_post_terms( $id, 'fw-portfolio-category') as $key2 => $s_item) {
                $category_array[$i][$key2] = array('slug' => $s_item->slug , 'name' => $s_item->name);
            }
            $i++;
        endwhile;

        $arrOut = array();
        foreach($category_array as $subArr){
            $arrOut = array_merge($arrOut,$subArr);
        }

        $category_array = array_map( 'unserialize', array_unique( array_map( 'serialize', $arrOut)));

        if($popup_mode == 'on') {
            $wrap_classes .= 'popup-gallery';
        }

        wp_enqueue_style('imate-custom-style', get_template_directory_uri() . '/css/custom_script.css');
        wp_add_inline_style( 'imate-custom-style', $custom_css );

        $html = "";

        if($autoplay == 'on') {
            $autoplay = 'true';
        } else {
            $autoplay = 'false';
        }

        if($arrows == 'on') {
            $arrows = 'true';
        } else {
            $arrows = 'false';
        }

        wp_enqueue_style( 'owl-carousel-css', get_template_directory_uri() . '/css/owl.carousel.css');
        wp_enqueue_script( 'owl-carousel-js', get_template_directory_uri() . '/js/owl.carousel.min.js', array('jquery'), true );
        wp_enqueue_script( 'imate-script', get_template_directory_uri() . '/js/script.js' );

        wp_add_inline_script('imate-script', "jQuery(document).ready(function(jQuery) {
            jQuery('.".esc_attr($wrap_id)."').each(function(){
                function showProjectsbyCat(cat) {
                    if (cat == 'all') {
                        jQuery('.".esc_attr($wrap_id)."-hidden .owl-item:not(.cloned) .item').each(function() {
                            var owl = jQuery('.".esc_attr($wrap_id)."'),
                                elem = jQuery(this).parent().html();
                            owl.trigger('add.owl.carousel', [elem]);
                            jQuery(this).parent().remove();
                            owl.trigger('refresh.owl.carousel').trigger('to.owl.carousel', [0]);
                        })
                    } else {
                        jQuery('.".esc_attr($wrap_id)."-hidden .item.' + cat).each(function() {
                            var owl = jQuery('.".esc_attr($wrap_id)."'),
                                elem = jQuery(this).parent().html();
                            owl.trigger('add.owl.carousel', [elem]);
                            jQuery(this).parent().remove();
                            owl.trigger('refresh.owl.carousel').trigger('to.owl.carousel', [0]);
                        });
                        jQuery('.".esc_attr($wrap_id)." .item:not(.' + cat + ')').each(function() {
                            var owl = jQuery('.".esc_attr($wrap_id)."'),
                                targetPos = jQuery(this).parent().index(),
                                elem = jQuery(this).parent();
                            jQuery(elem).clone().appendTo(jQuery('.".esc_attr($wrap_id)."-hidden'));
                            owl.trigger('remove.owl.carousel', [targetPos]);
                            owl.trigger('refresh.owl.carousel').trigger('to.owl.carousel', [0]);
                        })
                    }
                }

                var head_slider = jQuery(this);

                head_slider.prev('.filter-button-group').on('click', 'button', function(e){
                    e.preventDefault();
                    jQuery(this).addClass('active').siblings().removeClass('active');

                    var cat = jQuery(this).data('filter');
                    showProjectsbyCat( cat );
                });
                
                if(head_slider.find('.item').length > 1){
                    head_slider.on('initialized.owl.carousel initialize.owl.carousel refreshed.owl.carousel translated.owl.carousel', function() {
                        head_slider.find('.owl-item.active:first').prevAll().addClass('prev');
                        head_slider.find('.owl-item.active:first').removeClass('prev').nextAll().removeClass('prev');
                        head_slider.find('.owl-item.active:first').addClass('current').siblings().removeClass('current');
                    });

                    head_slider.addClass('owl-carousel').owlCarousel({
                        loop:true,
                        items:1,
                        nav: ".esc_js($arrows).",
                        dots: false,
                        autoWidth: true,
                        autoplay: ".esc_js($autoplay).",
                        autoplayTimeout: ".esc_js($autoplay_speed).",
                        autoplayHoverPause: false,
                        smartSpeed: ".esc_js($speed).",
                        navClass: ['owl-prev material-design-icon-keyboard-left-arrow-button','owl-next material-design-icon-keyboard-right-arrow-button'],
                        navText: false,
                        margin: 30,
                    });
                }
            });
        });");

        if(is_array($porfolio_array->posts) && count($porfolio_array->posts) > 0) {
            $html .= '<div class="portfolio-slider-w-filter-area">';
                if(is_array($category_array) && $filter_buttons == "on" && count($category_array) > 1) {
                    $html .= '<div class="filter-button-group container style2 '.esc_attr($filter_buttons_align).'">';
                        $html .= '<div class="wrap">';
                            $html .= '<button data-filter="all" class="active">'.esc_html__('All', 'image').'</button>';
                            foreach($category_array as $item) { 
                                $name = $item["name"];
                                $slug = $item["slug"];
                                $html .= '<button data-filter="category-'.esc_attr($slug).'">'.esc_html($name).'</button>';
                            }
                        $html .= '</div>';
                    $html .= '</div>';
                }
                $html .= '<div class="portfolio-slider-w-filter '.$wrap_id.' '.$wrap_classes.'">';
                    while ( $porfolio_array->have_posts() ) : $porfolio_array->the_post();
                        $id = get_the_ID();
                        $item = get_post($id);
                        $item_num++;
                        $name = $item->post_title;
                        $item_class = "";
                        for ($i=0; $i < count(wp_get_post_terms( $id, 'fw-portfolio-category')); $i++) { 
                            $item_class .= 'category-'.wp_get_post_terms( $id, 'fw-portfolio-category')[$i]->slug.' ';
                        }
                        $item_class = trim($item_class, ' ');
                        $thumb = get_post_meta( $id, '_thumbnail_id', true );
                        $image = wp_get_attachment_image_src( $thumb , 'large' );

                        if($popup_mode == 'off') {
                            $link = get_permalink($id);
                        } else {
                            $link = $image[0];
                            $item_class .= ' popup-item';
                        }

                        if($paged > 1) {
                            $num = $item_num+$paged*$count_items-$count_items-1;
                        } else {
                            $num = $item_num-1;
                        }

                        if(function_exists('get_field') && get_field('project_video_url', $id)) {
                            $item_class .= ' with-video';
                            $video_url = get_field('project_video_url', $id);
                            $video_url = VideoUrlParser::get_url_embed($video_url);
                        }

                        $html .= '<article class="item '.esc_attr($item_class).'">';
                            $html .= '<div class="wrap">';
                                $html .= '<div class="content">';
                                    if($show_heading == 'on') {
                                        $html .= '<h6 class="h">'.esc_html($name).'</h6>';
                                    }
                                    if($show_readmore == 'on') {
                                        $html .= '<div class="link"><span>'.esc_html__('view work', 'imate').'</span><i class="fa fa-angle-right"></i></div>';
                                    }
                                $html .= '</div>';
                                $html .= '<div class="a-img">'.wp_get_attachment_image( $thumb , 'large' ).'</div>';
                                if(function_exists('get_field') && get_field('project_video_url', $id)) {
                                    $html .= '<a href="#" data-type="video" data-size="960x640" data-id="'.esc_attr($num).'" data-video=\'<div class="wrapper"><div class="video-wrapper"><iframe class="pswp__video" width="1920" height="1080" src="'.esc_url($video_url).'" frameborder="0" allowfullscreen></iframe></div></div>\'></a>';
                                } else {
                                    $html .= '<a href="'.esc_url($link).'" data-size="'.esc_attr($image[1].'x'.$image[2]).'" data-id="'.esc_attr($num).'"></a>';
                                }
                            $html .= '</div>';
                        $html .= '</article>';
                    endwhile;
                    wp_reset_postdata();
                $html .= '</div>';
                $html .= '<div class="'.esc_attr($wrap_id).'-hidden hide"></div>';
            $html .= '</div>';
        }

        return $html;
         
    }
     
} // End Element Class
 
 
// Element Class Init
new PT_Portfolio_Slider_Filter();