<?php

// Element Description: PT Skills

class PT_Skills extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_skills_mapping' ) );
        add_shortcode( 'pt_skills', array( $this, 'pt_skills_html' ) );
        add_shortcode( 'pt_skills_item', array( $this, 'pt_skills_item_html' ) );
    }
     
    // Element Mapping
    public function pt_skills_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }

        vc_map( array(
            "name" => esc_html__("Skills", "imate"),
            "base" => "pt_skills",
            "as_parent" => array('only' => 'pt_skills_item'),
            "content_element" => true,
            "show_settings_on_create" => false,
            "icon" => "shortcode-icon-skills",
            "is_container" => true,
            "category" => esc_html__("By PT", "imate"),
            "params" => array(
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Desktop", "imate" ),
                    "param_name"  => "desktop_cols",
                    "value"      => array(
                        esc_html__( "Col 1", "imate" ) => "1",
                        esc_html__( "Col 2", "imate" ) => "2",
                        esc_html__( "Col 3", "imate" ) => "3",
                        esc_html__( "Col 4", "imate" ) => "4",
                    ),
                    "std" => '3',
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Tablet", "imate" ),
                    "param_name"  => "tablet_cols",
                    "value"      => array(
                        esc_html__( "Col 1", "imate" ) => "1",
                        esc_html__( "Col 2", "imate" ) => "2",
                        esc_html__( "Col 3", "imate" ) => "3",
                        esc_html__( "Col 4", "imate" ) => "4",
                    ),
                    "std" => '2',
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Mobile", "imate" ),
                    "param_name"  => "mobile_cols",
                    "value"      => array(
                        esc_html__( "Col 1", "imate" ) => "1",
                        esc_html__( "Col 2", "imate" ) => "2",
                        esc_html__( "Col 3", "imate" ) => "3",
                        esc_html__( "Col 4", "imate" ) => "4",
                    ),
                    "std" => '1',
                ),
                array(
                    "type" => "animation_style",
                    "heading" => esc_html__( "Animation In", "imate" ),
                    "param_name" => "animation",
                ),
                array(
                    'type' => 'css_editor',
                    'heading' => esc_html__( 'CSS box', 'imate' ),
                    'param_name' => 'css',
                    'group' => esc_html__( 'Design Options', 'imate' ),
                ),
            ),
            "js_view" => 'VcColumnView'
        ) );
        vc_map( array(
            "name" => esc_html__("Skills item", "imate"),
            "base" => "pt_skills_item",
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-skills",
            "as_child" => array('only' => 'pt_skills'),
            "params" => array(
                array(
                    "type"        => "textfield",
                    "heading"     => esc_html__( "Uniq ID", "imate" ),
                    "param_name"  => "uniq_id",
                    "value"       => uniqid(),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Type", "imate" ),
                    "param_name"  => "type",
                    "value"      => array(
                        esc_html__( "Line", "imate" ) => "line",
                        esc_html__( "Circle", "imate" ) => "circle",
                    ),
                ),
                array(
                    "type"        => "slider",
                    "heading"     => esc_html__( "Skill level", "imate" ),
                    "param_name"  => "skill_level",
                    "min"         => "0",
                    "max"         => "100",
                    "step"        => "1",
                    "admin_label" => true,
                ),
                array(
                    "type"        => "vc_link",
                    "heading"     => esc_html__( "Link", "imate" ),
                    "param_name"  => "link",
                    "admin_label" => true,
                ),
                array(
                    "type"        => "textarea",
                    "heading"     => esc_html__( "Heading", "imate" ),
                    "param_name"  => "heading",
                    "admin_label" => true,
                ),
                array(
                    "type"        => "textarea",
                    "heading"     => esc_html__( "Description", "imate" ),
                    "param_name"  => "desc",
                    "dependency"  => Array( "element" => "type", "value" => array( "line" ) ),
                ),
                
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Line color", "imate"),
                    "param_name" => "bg_color",
                ),
                array(
                    "type" => "number",
                    "heading" => esc_html__("Line thickness", "imate"),
                    "param_name" => "line_thickness",
                    "min"         => "1",
                    "max"         => "15",
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Empty line color", "imate"),
                    "param_name" => "empty_bg_color",
                    "dependency"  => Array( "element" => "type", "value" => array( "circle" ) ),
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Heading color", "imate"),
                    "param_name" => "nubers_color",
                ),
                array(
                    "type" => "animation_style",
                    "heading" => esc_html__( "Animation In", "imate" ),
                    "param_name" => "animation",
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Color overlay", "imate"),
                    "param_name" => "color_overlay",
                    "dependency"  => Array( "element" => "type", "value" => array( "circle" ) ),
                ),
            )
        ) );
    }
     
     
    // Element HTML
    public function pt_skills_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'desktop_cols' => '3',
                    'tablet_cols' => '2',
                    'mobile_cols' => '1',
                    'animation' => '',
                    'css' => '',
                ), 
                $atts
            )
        );

        $html = $item_css = '';

        if(!empty($css)) {
            $item_css .= ' '.vc_shortcode_custom_css_class( $css, ' ' );
        }
        
        $animation = $this->getCSSAnimation($animation);

        if(!empty($content)) {
            $content = str_replace('[pt_skills_item', '[pt_skills_item desktop_cols='.$desktop_cols.' tablet_cols='.$tablet_cols.' mobile_cols='.$mobile_cols.' animation='.$animation.' ', $content);
        }

        ob_start();
        ?>
            <div class="skill-items row<?php echo esc_attr($item_css) ?>">
                <?php echo do_shortcode($content) ?>
            </div>
        <?php
        return ob_get_clean();
         
    }

    public function pt_skills_item_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                    'type' => 'line',
                    'bg' => '',
                    'skill_level' => '',
                    'link' => '',
                    'heading' => '',
                    'desc' => '',
                    'bg_color' => '',
                    'empty_bg_color' => '',
                    'nubers_color' => '',
                    'animation' => '',
                    'color_overlay' => '',
                    'line_thickness' => '',
                    'desktop_cols' => '3',
                    'tablet_cols' => '2',
                    'mobile_cols' => '1',
                    'animation' => '',
                ), 
                $atts
            )
        );

        $html = $custom_css = '';
        $block_css = $id = uniqid('skill-item-');

        if(isset(vc_build_link($link)['url']) && !empty(vc_build_link($link)['url'])) {
            $link = vc_build_link($link);
        }

        if(!empty($bg_color)) {
            $custom_css .= '.'.$id.' .rating-line div {';
                $custom_css .= 'background: '.$bg_color.' !important;';
            $custom_css .= '}';
        }

        if(!empty($nubers_color)) {
            $custom_css .= '.'.$id.' h6, .'.$id.' .circle .skill-level {';
                $custom_css .= 'color: '.$nubers_color.';';
            $custom_css .= '}';
        }

        if(!empty($color_overlay)) {
            $custom_css .= '.'.$id.' .bg-image:after {
                content: "";
                position: absolute;
                top: 0;
                left: 0;
                right: 0; 
                bottom: 0; 
                z-index: 0;
                border-radius: 50%;
                background-color: '.$color_overlay.';
            }';
        }

        wp_enqueue_style('image-custom-style', get_template_directory_uri() . '/css/custom_script.css');
        wp_add_inline_style( 'imate-custom-style', $custom_css );
        
        if(!empty($animation)) {
            $block_css .= ' '.$animation;
        }

        $cols_css = 'col-xs-'.(12/$mobile_cols).' col-sm-'.(12/$tablet_cols).' col-md-'.(12/$desktop_cols);

        if($skill_level) {
            if($type == 'line') {
                $html .= '<div class="'.esc_attr($cols_css).'">';
                    $html .= '<div class="skill-item '.esc_attr($block_css).'">';
                        if($heading) {
                            if(!empty($link) && !empty($link['url'])) {
                                if(empty($link['target'])) {
                                    $link['target'] = '_self';
                                }
                                $html .= '<h6><a href="'.esc_url($link['url']).'" target="'.esc_attr($link['target']).'"><span>'.wp_kses_post($heading).'</span></a></h6>';
                            } else {
                                $html .= '<h6>'.wp_kses_post($heading).'</h6>';
                            }
                        }
                        $html .= '<div class="rating-line" data-percent="'.esc_attr($skill_level).'"><div class="line" style="width: 0%; background: '.$bg_color.'; height: '.$line_thickness.'px"></div><span>'.esc_attr($skill_level).'%</span></div>';

                        if(!empty($desc)) {
                            $html .= '<div class="desc">'.wp_kses_post($desc).'</div>';
                        }
                    $html .= '</div>';
                $html .= '</div>';
            } else {
                if(empty($empty_bg_color)) {
                    $empty_bg_color = '#d1d6d9';
                }
                if(empty($bg_color)) {
                    $bg_color = '#ed4266';
                    if(!empty(imate_styles()['color_scheme'])) {
                        $bg_color = imate_styles()['color_scheme'];
                    }
                }
                wp_enqueue_script( 'circle-progress', get_template_directory_uri() . '/js/circle-progress.min.js', array('jquery'), true );;

                if(empty($line_thickness)) {
                    $line_thickness = '7';
                }
                wp_add_inline_script('imate-script', "jQuery(document).ready(function(jQuery) {
                    jQuery('.".esc_attr($id)." .circle').each(function(){
                        jQuery(this).circleProgress({
                            emptyFill:  '".$empty_bg_color."',
                            fill:       '".$bg_color."',
                            thickness:  ".$line_thickness.",
                            startAngle: -190
                        });
                    });
                });");
                $html .= '<div class="'.esc_attr($cols_css).'">';
                    $html .= '<div class="skill-item-circle '.esc_attr($block_css).'">';
                        $html .= '<div class="circle" data-value="'.esc_attr($skill_level/100).'" data-size="125">';
                            $html .= '<div class="skill-level">'.esc_html($skill_level).'<span>%</span>';
                        $html .= '</div></div>';
                      
                        if($heading) {
                            if(!empty($link) && !empty($link['url'])) {
                                if(empty($link['target'])) {
                                    $link['target'] = '_self';
                                }
                                $html .= '<h5 class="h"><a href="'.esc_url($link['url']).'" target="'.esc_attr($link['target']).'"><span>'.wp_kses_post($heading).'</span></a></h5>';
                            } else {
                                $html .= '<h5 class="h">'.wp_kses_post($heading).'</h5>';
                            }
                        }
                    $html .= '</div>';
                $html .= '</div>';
            }
        }

        return $html;
         
    }
     
} // End Element Class
 
// Element Class Init
new PT_Skills();
if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
    class WPBakeryShortCode_PT_Skills extends WPBakeryShortCodesContainer {
    }
}
if ( class_exists( 'WPBakeryShortCode' ) ) {
    class WPBakeryShortCode_PT_Skills_Item extends WPBakeryShortCode {
    }
}