<?php

// Element Description: PT Social Links

class PT_Social_Links extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_social_links_mapping' ) );
        add_shortcode( 'pt_social_links', array( $this, 'pt_social_links_html' ) );
        add_shortcode( 'pt_social_links_item', array( $this, 'pt_social_links_item_html' ) );
    }
     
    // Element Mapping
    public function pt_social_links_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Social Links", "imate"),
            "base" => "pt_social_links",
            "as_parent" => array('only' => 'pt_social_links_item'),
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-social-links",
            //"is_container" => true,
            "category" => esc_html__("By PT", "imate"),
            "params" => array(
                /*array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Style", "imate" ),
                    "param_name"  => "style",
                    "value"      => array(
                        esc_html__( "Style 1", "imate" ) => "style1",
                        esc_html__( "Style 2", "imate" ) => "style2",
                    ),
                ),*/
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Link align", "imate" ),
                    "param_name"  => "text_align",
                    "value"      => array(
                        esc_html__( "Left", "imate" ) => "tal",
                        esc_html__( "Center", "imate" ) => "tac",
                        esc_html__( "Right", "imate" ) => "tar",
                    ),
                    "std" => "tac",
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__( "Icon size", "imate" ),
                    "param_name" => "icon_size",
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__( "Icon color", "imate" ),
                    "param_name" => "icon_color",
                ),
                array(
                    "type" => "animation_style",
                    "heading" => esc_html__( "Animation In", "imate" ),
                    "param_name" => "animation",
                ),
                array(
                    'type' => 'css_editor',
                    'heading' => esc_html__( 'CSS box', 'imate' ),
                    'param_name' => 'css',
                    'group' => esc_html__( 'Design Options', 'imate' ),
                ),
            ),
            "js_view" => 'VcColumnView'
        ) );
        vc_map( array(
            "name" => esc_html__("Social Link", "imate"),
            "base" => "pt_social_links_item",
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-social-links",
            "as_child" => array('only' => 'pt_social_links'),
            "params" => array(
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Social Network", "imate" ),
                    "param_name"  => "social_network",
                    "value"       => array(
                        esc_html__('500px', 'imate') => 'fa fa-500px,500px',
                        esc_html__('App.net', 'imate') => 'fa fa-adn,App.net',
                        esc_html__('Bitbucket', 'imate') => 'fa fa-bitbucket,Bitbucket',
                        esc_html__('Behance', 'imate') => 'social-media-elements-behance,Behance',
                        esc_html__('Dribble', 'imate') => 'social-media-elements-dribble,Dribble',
                        esc_html__('Dropbox', 'imate') => 'social-media-elements-dropbox,Dropbox',
                        esc_html__('Facebook', 'imate') => 'social-media-elements-facebook,Facebook',
                        esc_html__('Flickr', 'imate') => 'social-media-elements-flickr,Flickr',
                        esc_html__('Foursquare', 'imate') => 'social-media-elements-foursquare,Foursquare',
                        esc_html__('GitHub', 'imate') => 'fa fa-github,GitHub',
                        esc_html__('Google', 'imate') => 'social-media-elements-google-plus,Google',
                        esc_html__('Instagram', 'imate') => 'social-media-elements-instagram,Instagram',
                        esc_html__('LinkedIn', 'imate') => 'social-media-elements-linkedin,LinkedIn',
                        esc_html__('Windows', 'imate') => 'fa fa-windows,Windows',
                        esc_html__('Odnoklassniki', 'imate') => 'fa fa-odnoklassniki,Odnoklassniki',
                        esc_html__('OpenID', 'imate') => 'fa fa-openid,OpenID',
                        esc_html__('Pinterest', 'imate') => 'social-media-elements-pinterest,Pinterest',
                        esc_html__('Reddit', 'imate') => 'fa fa-reddit,Reddit',
                        esc_html__('SoundCloud', 'imate') => 'social-media-elements-soundcloud,SoundCloud',
                        esc_html__('Tumblr', 'imate') => 'social-media-elements-tumblr,Tumblr',
                        esc_html__('Twitter', 'imate') => 'social-media-elements-twitter,Twitter',
                        esc_html__('Vimeo', 'imate') => 'social-media-elements-vimeo,Vimeo',
                        esc_html__('VK', 'imate') => 'social-media-elements-vk,VK',
                        esc_html__('Yahoo', 'imate') => 'social-media-elements-yahoo,Yahoo',
                        esc_html__('Youtube', 'imate') => 'social-media-elements-youtube,Youtube',
                    ),
                    "admin_label" => true,
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Link", "imate"),
                    "param_name" => "link",
                    "admin_label" => true,
                ),
            ),
        ) );
    }
     
     
    // Element HTML
    public function pt_social_links_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                    'style' => 'style1',
                    'text_align' => 'tac',
                    'icon_size' => '',
                    'icon_color' => '',
                    'animation' => '',
                    'css' => ''
                ), 
                $atts
            )
        );

        $items_class = $id = 'social-links-'.$uniq_id;

        if($style == 'style1') {
            $items_class .= ' social-buttons';
        } else {
            $items_class .= ' social-links-s2';
        }

        $items_class .= ' '.$text_align;

        if(!empty($animation)) {
            $items_class .= ' '.$this->getCSSAnimation($animation);
        }

        if(!empty($css)) {
            $items_class .= ' '.vc_shortcode_custom_css_class( $css );
        }

        if(!empty($icon_size)) {
            $custom_css = '.'.$id.' {
                font-size: '.$icon_size.';
            }';
        }

        if(!empty($icon_color)) {
            $custom_css = '.'.$id.' i {
                color: '.$icon_color.';
            }';
        }

        if(!empty($custom_css)) {
            wp_enqueue_style('imate-custom-style', get_template_directory_uri() . '/css/custom_script.css');
            wp_add_inline_style( 'imate-custom-style', $custom_css );
        }

        if(!empty($content)) {
            $content = str_replace('[pt_social_links_item', '[pt_social_links_item style="'.esc_attr($style).'"', $content);
        }

        $html = '<div class="'.esc_attr($items_class).'">';
            $html .= do_shortcode($content);
        $html .= '</div>';
         
        return $html;
         
    }

    // Element HTML
    public function pt_social_links_item_html( $atts ) {

        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'style' => 'style1',
                    'social_network' => 'fa fa-500px,500px',
                    'link' => '',
                    'html' => ''
                ), 
                $atts
            )
        );
        
        // Fill $html var with data

        $array = explode(',', $social_network);

        if(!empty($link)) {
            $html = '<a href="'.esc_url($link).'" target="_blank"><i class="'.esc_attr($array[0]).'"></i><span>'.strip_tags($array[1]).'</span></a>';
        }

        return $html;
         
    }
     
} // End Element Class
 
 
// Element Class Init
new PT_Social_Links();    
if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
    class WPBakeryShortCode_PT_Social_Links extends WPBakeryShortCodesContainer {
    }
}
if ( class_exists( 'WPBakeryShortCode' ) ) {
    class WPBakeryShortCode_PT_Social_Links_Item extends WPBakeryShortCode {
    }
}

