<?php

// Element Description: PT Special Heading

class PT_Special_Heading extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_special_heading_mapping' ) );
        add_shortcode( 'pt_special_heading', array( $this, 'pt_special_heading_html' ) );
    }
     
    // Element Mapping
    public function pt_special_heading_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Special Heading", "imate"),
            "base" => "pt_special_heading",
            "as_parent" => array('only' => 'pt_special_heading_item'),
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-special-heading",
            "category" => esc_html__("By PT", "imate"),
            "params" => array(
                array(
                    "type"        => "el_id",
                    "heading"     => esc_html__( "Uniq ID", "imate" ),
                    "param_name"  => "uniq_id",
                    "value"       => uniqid(),
                    "group"       => esc_html__("General", "imate"),
                ),
                array(
                    "type" => "textarea",
                    "heading" => esc_html__("Sub Heading", "imate"),
                    "param_name" => "sub_heading",
                    "admin_label" => true,
                    "group"      => esc_html__("General", "imate"),
                ),
                array(
                    "type" => "textarea",
                    "heading" => esc_html__("Heading", "imate"),
                    "param_name" => "heading",
                    "admin_label" => true,
                    "description" => __("Wrap the text in { } if you want the text to be another color.<br>Example: Minds your work {level}", "imate"),
                    "group"      => esc_html__("General", "imate"),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Heading size", "imate" ),
                    "param_name"  => "heading_size",
                    "value"      => array(
                        esc_html__( "H1", "imate" ) => "h1",
                        esc_html__( "H2", "imate" ) => "h2",
                        esc_html__( "H3", "imate" ) => "h3",
                        esc_html__( "H4", "imate" ) => "h4",
                        esc_html__( "H5", "imate" ) => "h5",
                        esc_html__( "H6", "imate" ) => "h6",
                    ),
                    "std"         => "h2",
                    "group"       => esc_html__("General", "imate"),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Heading decor", "imate" ),
                    "param_name"  => "heading_decor",
                    "value"      => array(
                        esc_html__( "None", "imate" ) => "",
                        esc_html__( "Line on bottom", "imate" ) => "bottom",
                    ),
                    "group"       => esc_html__("General", "imate"),
                ),
                array(
                    "type" => "animation_style",
                    "heading" => esc_html__( "Animation In", "imate" ),
                    "param_name" => "animation",
                    "group"      => esc_html__("General", "imate"),
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Heading font size", "imate"),
                    "param_name" => "heading_size_value",
                    "group"      => esc_html__("Design", "imate"),
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Sub Heading font size", "imate"),
                    "param_name" => "sub_heading_size_value",
                    "group"      => esc_html__("Design", "imate"),
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Sub Heading Color", "imate"),
                    "param_name" => "sub_heading_color_hex",
                    "group"      => esc_html__("Design", "imate"),
                ),
                array(
                    "type" => "colorpicker",
                    "heading" => esc_html__("Heading Color", "imate"),
                    "param_name" => "heading_color_hex",
                    "group"      => esc_html__("Design", "imate"),
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Letter spacing", "imate"),
                    "param_name" => "letter_spacing",
                    "group"      => esc_html__("Design", "imate"),
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Line height", "imate"),
                    "param_name" => "line_height",
                    "group"      => esc_html__("Design", "imate"),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Text align", "imate" ),
                    "param_name"  => "text_align",
                    "value"      => array(
                        esc_html__( "Left", "imate" ) => "tal",
                        esc_html__( "Center", "imate" ) => "tac",
                        esc_html__( "Right", "imate" ) => "tar",
                    ),
                    "std" => "tal",
                    "group"       => esc_html__("Design", "imate"),
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Heading uppercase", "imate" ),
                    "param_name"  => "heading_uppercase",
                    "value"       => "off",
                    "options"     => array(
                        "on" => array(
                            "on"    => esc_html__("On", "imate"),
                            "off"   => esc_html__("Off", "imate"),
                        ),
                    ),
                    "default_set" => true,
                    "group"       => esc_html__("Design", "imate"),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Font weight", "imate" ),
                    "param_name"  => "font_weight",
                    "value"      => array(
                        esc_html__( "Default", "imate" ) => "default",
                        esc_html__( "Extra Light", "imate" ) => "100",
                        esc_html__( "Light", "imate" ) => "200",
                        esc_html__( "Book", "imate" ) => "300",
                        esc_html__( "Regular", "imate" ) => "400",
                        esc_html__( "Medium", "imate" ) => "500",
                        esc_html__( "Semibold", "imate" ) => "600",
                        esc_html__( "Bold", "imate" ) => "700",
                    ),
                    "std" => "default",
                    "group"       => esc_html__("Design", "imate"),
                ),
                array(
                    'type' => 'css_editor',
                    'heading' => esc_html__( 'CSS box', 'imate' ),
                    'param_name' => 'css',
                    'group' => esc_html__( 'Design Options', 'imate' ),
                ),
            ),
        ) );
    }
     
     
    // Element HTML
    public function pt_special_heading_html( $atts ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                    'sub_heading' => '',
                    'heading' => '',
                    'heading_size' => 'h2',
                    'heading_uppercase' => 'off',
                    'heading_decor' => '',
                    'decor_line' => 'off',
                    'animation' => '',
                    'heading_size_value' => '',
                    'sub_heading_size_value' => '',
                    'sub_heading_color_hex' => '',
                    'letter_spacing' => '',
                    'line_height' => '',
                    'heading_color_hex' => '',
                    'text_align' => 'tal',
                    'font_weight' => 'default',
                    'css' => '',
                ), 
                $atts
            )
        );

        if(empty($uniq_id)) {
            $uniq_id = uniqid();
        }

        $item_css = $item_id = 'pt-special-heading-'.$uniq_id;

        $heading_class = $custom_css = "";

        $item_css .= ' '.$this->getCSSAnimation($animation).' '.$text_align;

        if(isset($sub_heading_color_hex) && !empty($sub_heading_color_hex)) {
            $custom_css .= '.'.$item_id.' .sub-h {
                color: '.$sub_heading_color_hex.';
            }';
        }

        if(isset($heading_color_hex) && !empty($heading_color_hex)) {
            $custom_css .= '.'.$item_id.' {
                color: '.$heading_color_hex.';
            }';
        }

        if(isset($sub_heading_size_value) && !empty($sub_heading_size_value)) {
            $custom_css .= '.'.$item_id.' .sub-h {
                font-size: '.$sub_heading_size_value.';
            }';
        }

        if(isset($heading_size_value) && !empty($heading_size_value)) {
            $custom_css .= '.'.$item_id.' .heading {
                font-size: '.$heading_size_value.';
            }';
        }

        if(isset($letter_spacing) && !empty($letter_spacing)) {
            $custom_css .= '.'.$item_id.' .heading {
                letter-spacing: '.$letter_spacing.';
            }';
        }

        if(isset($line_height) && !empty($line_height)) {
            $custom_css .= '.'.$item_id.' .heading {
                line-height: '.$line_height.';
            }';
        }

        if(!empty($css)) {
            $item_css .= ' '.vc_shortcode_custom_css_class( $css, ' ' );
        }

        if($heading_decor == 'bottom') {
            $item_css .= ' decor-line-on-bottom';
        } else if($heading_decor == 'bg-letter') {
            $item_css .= ' bg-letter';
        }

        if($heading_uppercase == 'on') {
            $heading_class .= ' uppercase';
        }

        if($font_weight != 'default') {
            $heading_class .= ' fw-'.$font_weight;
        }

        wp_enqueue_style('imate-custom-style', get_template_directory_uri() . '/css/custom_script.css');
        wp_add_inline_style( 'imate-custom-style', $custom_css );

        $html = '<div class="pt-special-heading '.esc_attr($item_css).'">';
            if(!empty($sub_heading)) {
                $html .= '<div class="sub-h decor-h"><span>'.wp_kses_post($sub_heading).'</span></div>';
            }
            if(!empty($heading)) {
                $heading = str_replace(array('{', '}'), array('<span>', '</span>'), $heading);
                $html .= '<'.esc_attr($heading_size).' class="heading'.esc_attr($heading_class).'"><i>'.wp_kses_post($heading).'</i></'.esc_attr($heading_size).'>';
            }
        $html .= '</div>';

        return $html;
         
    }
     
} // End Element Class
 
 
// Element Class Init
new PT_Special_Heading();    
if ( class_exists( 'WPBakeryShortCode' ) ) {
    class WPBakeryShortCode_PT_Special_Heading extends WPBakeryShortCode {
    }
}
