<?php

// Element Description: PT Team

class PT_Team extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_team_mapping' ) );
        add_shortcode( 'pt_team', array( $this, 'pt_team_html' ) );
        add_shortcode( 'pt_team_item', array( $this, 'pt_team_item_html' ) );
    }
     
    // Element Mapping
    public function pt_team_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Team", "imate"),
            "base" => "pt_team",
            "as_parent" => array('only' => 'pt_team_item'),
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-team",
            "is_container" => true,
            "category" => esc_html__("By PT", "imate"),
            "params" => array(
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Carousel", "imate" ),
                    "param_name"  => "carousel",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => "Yes",
                            "off"   => "No",
                        ),
                    ),
                    "dependency"  => "",
                    "default_set" => true,
                    "group"       => esc_html__( "General", "imate" ),
                ),
                array(
                    "type"        => "number",
                    "class"       => "",
                    "heading"     => esc_html__( "Transition speed", "imate" ),
                    "param_name"  => "speed",
                    "value"       => "300",
                    "min"         => "100",
                    "max"         => "10000",
                    "step"        => "100",
                    "suffix"      => "ms",
                    "dependency" => Array( "element" => "carousel", "value" => array( "on" ) ),
                    "group"       => esc_html__( "Carousel Settings", "imate" ),
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Autoplay Slides", "imate" ),
                    "param_name"  => "autoplay",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "label" => esc_html__( "Enable Autoplay", "imate" ),
                            "on"    => "Yes",
                            "off"   => "No",
                        ),
                    ),
                    "dependency"  => "",
                    "default_set" => true,
                    "dependency" => Array( "element" => "carousel", "value" => array( "on" ) ),
                    "group"       => esc_html__( "Carousel Settings", "imate" ),
                ),
                array(
                    "type"       => "number",
                    "heading"    => esc_html__( "Autoplay Speed", "imate" ),
                    "param_name" => "autoplay_speed",
                    "value"      => "5000",
                    "min"        => "100",
                    "max"        => "10000",
                    "step"       => "10",
                    "suffix"     => "ms",
                    "dependency" => Array( "element" => "carousel", "value" => array( "on" ) ),
                    "group"       => esc_html__( "Carousel Settings", "imate" ),
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Navigation Arrows", "imate" ),
                    "param_name"  => "arrows",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => "On",
                            "off"   => "Off",
                        ),
                    ),
                    "default_set" => true,
                    "dependency" => Array( "element" => "carousel", "value" => array( "on" ) ),
                    "group"       => esc_html__( "Carousel Settings", "imate" ),
                ),
                array(
                    "type"        => "switch",
                    "class"       => "",
                    "heading"     => esc_html__( "Pagination Dots", "imate" ),
                    "param_name"  => "dots",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => "On",
                            "off"   => "Off",
                        ),
                    ),
                    "default_set" => true,
                    "dependency" => Array( "element" => "carousel", "value" => array( "on" ) ),
                    "group"       => esc_html__( "Carousel Settings", "imate" ),
                ),
                array(
                    "type"       => "colorpicker",
                    "heading"    => esc_html__( "Pagination Dots Color", "imate" ),
                    "param_name" => "dots_color",
                    "dependency" => Array( "element" => "dots", "value" => array( "on" ) ),
                    "group"       => esc_html__( "Carousel Settings", "imate" ),
                ),
                array(
                    "type"       => "switch",
                    "heading"    => esc_html__( "Pause on hover", "imate" ),
                    "param_name" => "pauseohover",
                    "value"      => "on",
                    "options"    => array(
                        "on" => array(
                            "label" => esc_html__( "Pause the slider on hover", "imate" ),
                            "on"    => "Yes",
                            "off"   => "No",
                        ),
                    ),
                    "dependency" => Array("element" => "autoplay", "value" => "on" ),
                    "group"       => esc_html__( "Carousel Settings", "imate" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Desktop", "imate" ),
                    "param_name"  => "desktop_cols",
                    "value"      => array(
                        esc_html__( "Col 1", "imate" ) => "1",
                        esc_html__( "Col 2", "imate" ) => "2",
                        esc_html__( "Col 3", "imate" ) => "3",
                        esc_html__( "Col 4", "imate" ) => "4",
                    ),
                    "std" => '3',
                    "group"       => esc_html__( "General", "imate" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Tablet", "imate" ),
                    "param_name"  => "tablet_cols",
                    "value"      => array(
                        esc_html__( "Col 1", "imate" ) => "1",
                        esc_html__( "Col 2", "imate" ) => "2",
                        esc_html__( "Col 3", "imate" ) => "3",
                        esc_html__( "Col 4", "imate" ) => "4",
                    ),
                    "std" => '2',
                    "group"       => esc_html__( "General", "imate" ),
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Mobile", "imate" ),
                    "param_name"  => "mobile_cols",
                    "value"      => array(
                        esc_html__( "Col 1", "imate" ) => "1",
                        esc_html__( "Col 2", "imate" ) => "2",
                        esc_html__( "Col 3", "imate" ) => "3",
                        esc_html__( "Col 4", "imate" ) => "4",
                    ),
                    "std" => '1',
                    "group"       => esc_html__( "General", "imate" ),
                ),
                array(
                    "type" => "animation_style",
                    "heading" => esc_html__( "Animation In", "imate" ),
                    "param_name" => "animation",
                    "group"       => esc_html__( "General", "imate" ),
                ),
            ),
            "js_view" => 'VcColumnView'
        ) );
        vc_map( array(
            "name" => esc_html__("Team item", "imate"),
            "base" => "pt_team_item",
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-team",
            "as_child" => array('only' => 'pt_team'),
            "params" => array(
                array(
                    "type" => "attach_image",
                    "heading" => esc_html__("Avatar", "imate"),
                    "param_name" => "avatar",
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Name", "imate"),
                    "param_name" => "name",
                    "admin_label" => true,
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Post", "imate"),
                    "param_name" => "post",
                    "admin_label" => true,
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Social icon 1", "imate" ),
                    "edit_field_class" => "vc_col-xs-6",
                    "param_name"  => "social_icon_1",
                    "value"      => array(
                        esc_html__('---', 'imate') => "",
                        esc_html__('500px', 'imate') => 'fa fa-500px,500px',
                        esc_html__('App.net', 'imate') => 'fa fa-adn,App.net',
                        esc_html__('Bitbucket', 'imate') => 'fa fa-bitbucket,Bitbucket',
                        esc_html__('Behance', 'imate') => 'social-media-elements-behance,Behance',
                        esc_html__('Dribble', 'imate') => 'social-media-elements-dribble,Dribble',
                        esc_html__('Dropbox', 'imate') => 'social-media-elements-dropbox,Dropbox',
                        esc_html__('Facebook', 'imate') => 'social-media-elements-facebook,Facebook',
                        esc_html__('Flickr', 'imate') => 'social-media-elements-flickr,Flickr',
                        esc_html__('Foursquare', 'imate') => 'social-media-elements-foursquare,Foursquare',
                        esc_html__('GitHub', 'imate') => 'fa fa-github,GitHub',
                        esc_html__('Google', 'imate') => 'social-media-elements-google-plus,Google',
                        esc_html__('Instagram', 'imate') => 'social-media-elements-instagram,Instagram',
                        esc_html__('LinkedIn', 'imate') => 'social-media-elements-linkedin,LinkedIn',
                        esc_html__('Windows', 'imate') => 'fa fa-windows,Windows',
                        esc_html__('Odnoklassniki', 'imate') => 'fa fa-odnoklassniki,Odnoklassniki',
                        esc_html__('OpenID', 'imate') => 'fa fa-openid,OpenID',
                        esc_html__('Pinterest', 'imate') => 'social-media-elements-pinterest,Pinterest',
                        esc_html__('Reddit', 'imate') => 'fa fa-reddit,Reddit',
                        esc_html__('SoundCloud', 'imate') => 'social-media-elements-soundcloud,SoundCloud',
                        esc_html__('Tumblr', 'imate') => 'social-media-elements-tumblr,Tumblr',
                        esc_html__('Twitter', 'imate') => 'social-media-elements-twitter,Twitter',
                        esc_html__('Vimeo', 'imate') => 'social-media-elements-vimeo,Vimeo',
                        esc_html__('VK', 'imate') => 'social-media-elements-vk,VK',
                        esc_html__('Yahoo', 'imate') => 'social-media-elements-yahoo,Yahoo',
                        esc_html__('Youtube', 'imate') => 'social-media-elements-youtube,Youtube',
                    ),
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Social link 1", "imate"),
                    "edit_field_class" => "vc_col-xs-6",
                    "param_name" => "social_link_1",
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Social icon 2", "imate" ),
                    "edit_field_class" => "vc_col-xs-6",
                    "param_name"  => "social_icon_2",
                    "value"      => array(
                        esc_html__('---', 'imate') => "",
                        esc_html__('500px', 'imate') => 'fa fa-500px,500px',
                        esc_html__('App.net', 'imate') => 'fa fa-adn,App.net',
                        esc_html__('Bitbucket', 'imate') => 'fa fa-bitbucket,Bitbucket',
                        esc_html__('Behance', 'imate') => 'social-media-elements-behance,Behance',
                        esc_html__('Dribble', 'imate') => 'social-media-elements-dribble,Dribble',
                        esc_html__('Dropbox', 'imate') => 'social-media-elements-dropbox,Dropbox',
                        esc_html__('Facebook', 'imate') => 'social-media-elements-facebook,Facebook',
                        esc_html__('Flickr', 'imate') => 'social-media-elements-flickr,Flickr',
                        esc_html__('Foursquare', 'imate') => 'social-media-elements-foursquare,Foursquare',
                        esc_html__('GitHub', 'imate') => 'fa fa-github,GitHub',
                        esc_html__('Google', 'imate') => 'social-media-elements-google-plus,Google',
                        esc_html__('Instagram', 'imate') => 'social-media-elements-instagram,Instagram',
                        esc_html__('LinkedIn', 'imate') => 'social-media-elements-linkedin,LinkedIn',
                        esc_html__('Windows', 'imate') => 'fa fa-windows,Windows',
                        esc_html__('Odnoklassniki', 'imate') => 'fa fa-odnoklassniki,Odnoklassniki',
                        esc_html__('OpenID', 'imate') => 'fa fa-openid,OpenID',
                        esc_html__('Pinterest', 'imate') => 'social-media-elements-pinterest,Pinterest',
                        esc_html__('Reddit', 'imate') => 'fa fa-reddit,Reddit',
                        esc_html__('SoundCloud', 'imate') => 'social-media-elements-soundcloud,SoundCloud',
                        esc_html__('Tumblr', 'imate') => 'social-media-elements-tumblr,Tumblr',
                        esc_html__('Twitter', 'imate') => 'social-media-elements-twitter,Twitter',
                        esc_html__('Vimeo', 'imate') => 'social-media-elements-vimeo,Vimeo',
                        esc_html__('VK', 'imate') => 'social-media-elements-vk,VK',
                        esc_html__('Yahoo', 'imate') => 'social-media-elements-yahoo,Yahoo',
                        esc_html__('Youtube', 'imate') => 'social-media-elements-youtube,Youtube',
                    ),
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Social link 2", "imate"),
                    "edit_field_class" => "vc_col-xs-6",
                    "param_name" => "social_link_2",
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Social icon 3", "imate" ),
                    "edit_field_class" => "vc_col-xs-6",
                    "param_name"  => "social_icon_3",
                    "value"      => array(
                        esc_html__('---', 'imate') => "",
                        esc_html__('500px', 'imate') => 'fa fa-500px,500px',
                        esc_html__('App.net', 'imate') => 'fa fa-adn,App.net',
                        esc_html__('Bitbucket', 'imate') => 'fa fa-bitbucket,Bitbucket',
                        esc_html__('Behance', 'imate') => 'social-media-elements-behance,Behance',
                        esc_html__('Dribble', 'imate') => 'social-media-elements-dribble,Dribble',
                        esc_html__('Dropbox', 'imate') => 'social-media-elements-dropbox,Dropbox',
                        esc_html__('Facebook', 'imate') => 'social-media-elements-facebook,Facebook',
                        esc_html__('Flickr', 'imate') => 'social-media-elements-flickr,Flickr',
                        esc_html__('Foursquare', 'imate') => 'social-media-elements-foursquare,Foursquare',
                        esc_html__('GitHub', 'imate') => 'fa fa-github,GitHub',
                        esc_html__('Google', 'imate') => 'social-media-elements-google-plus,Google',
                        esc_html__('Instagram', 'imate') => 'social-media-elements-instagram,Instagram',
                        esc_html__('LinkedIn', 'imate') => 'social-media-elements-linkedin,LinkedIn',
                        esc_html__('Windows', 'imate') => 'fa fa-windows,Windows',
                        esc_html__('Odnoklassniki', 'imate') => 'fa fa-odnoklassniki,Odnoklassniki',
                        esc_html__('OpenID', 'imate') => 'fa fa-openid,OpenID',
                        esc_html__('Pinterest', 'imate') => 'social-media-elements-pinterest,Pinterest',
                        esc_html__('Reddit', 'imate') => 'fa fa-reddit,Reddit',
                        esc_html__('SoundCloud', 'imate') => 'social-media-elements-soundcloud,SoundCloud',
                        esc_html__('Tumblr', 'imate') => 'social-media-elements-tumblr,Tumblr',
                        esc_html__('Twitter', 'imate') => 'social-media-elements-twitter,Twitter',
                        esc_html__('Vimeo', 'imate') => 'social-media-elements-vimeo,Vimeo',
                        esc_html__('VK', 'imate') => 'social-media-elements-vk,VK',
                        esc_html__('Yahoo', 'imate') => 'social-media-elements-yahoo,Yahoo',
                        esc_html__('Youtube', 'imate') => 'social-media-elements-youtube,Youtube',
                    ),
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Social link 3", "imate"),
                    "edit_field_class" => "vc_col-xs-6",
                    "param_name" => "social_link_3",
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Social icon 4", "imate" ),
                    "edit_field_class" => "vc_col-xs-6",
                    "param_name"  => "social_icon_4",
                    "value"      => array(
                        esc_html__('---', 'imate') => "",
                        esc_html__('500px', 'imate') => 'fa fa-500px,500px',
                        esc_html__('App.net', 'imate') => 'fa fa-adn,App.net',
                        esc_html__('Bitbucket', 'imate') => 'fa fa-bitbucket,Bitbucket',
                        esc_html__('Behance', 'imate') => 'social-media-elements-behance,Behance',
                        esc_html__('Dribble', 'imate') => 'social-media-elements-dribble,Dribble',
                        esc_html__('Dropbox', 'imate') => 'social-media-elements-dropbox,Dropbox',
                        esc_html__('Facebook', 'imate') => 'social-media-elements-facebook,Facebook',
                        esc_html__('Flickr', 'imate') => 'social-media-elements-flickr,Flickr',
                        esc_html__('Foursquare', 'imate') => 'social-media-elements-foursquare,Foursquare',
                        esc_html__('GitHub', 'imate') => 'fa fa-github,GitHub',
                        esc_html__('Google', 'imate') => 'social-media-elements-google-plus,Google',
                        esc_html__('Instagram', 'imate') => 'social-media-elements-instagram,Instagram',
                        esc_html__('LinkedIn', 'imate') => 'social-media-elements-linkedin,LinkedIn',
                        esc_html__('Windows', 'imate') => 'fa fa-windows,Windows',
                        esc_html__('Odnoklassniki', 'imate') => 'fa fa-odnoklassniki,Odnoklassniki',
                        esc_html__('OpenID', 'imate') => 'fa fa-openid,OpenID',
                        esc_html__('Pinterest', 'imate') => 'social-media-elements-pinterest,Pinterest',
                        esc_html__('Reddit', 'imate') => 'fa fa-reddit,Reddit',
                        esc_html__('SoundCloud', 'imate') => 'social-media-elements-soundcloud,SoundCloud',
                        esc_html__('Tumblr', 'imate') => 'social-media-elements-tumblr,Tumblr',
                        esc_html__('Twitter', 'imate') => 'social-media-elements-twitter,Twitter',
                        esc_html__('Vimeo', 'imate') => 'social-media-elements-vimeo,Vimeo',
                        esc_html__('VK', 'imate') => 'social-media-elements-vk,VK',
                        esc_html__('Yahoo', 'imate') => 'social-media-elements-yahoo,Yahoo',
                        esc_html__('Youtube', 'imate') => 'social-media-elements-youtube,Youtube',
                    ),
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Social link 4", "imate"),
                    "edit_field_class" => "vc_col-xs-6",
                    "param_name" => "social_link_4",
                ),
                array(
                    "type"        => "dropdown",
                    "heading"     => esc_html__( "Social icon 5", "imate" ),
                    "edit_field_class" => "vc_col-xs-6",
                    "param_name"  => "social_icon_5",
                    "value"      => array(
                        esc_html__('---', 'imate') => "",
                        esc_html__('500px', 'imate') => 'fa fa-500px,500px',
                        esc_html__('App.net', 'imate') => 'fa fa-adn,App.net',
                        esc_html__('Bitbucket', 'imate') => 'fa fa-bitbucket,Bitbucket',
                        esc_html__('Behance', 'imate') => 'social-media-elements-behance,Behance',
                        esc_html__('Dribble', 'imate') => 'social-media-elements-dribble,Dribble',
                        esc_html__('Dropbox', 'imate') => 'social-media-elements-dropbox,Dropbox',
                        esc_html__('Facebook', 'imate') => 'social-media-elements-facebook,Facebook',
                        esc_html__('Flickr', 'imate') => 'social-media-elements-flickr,Flickr',
                        esc_html__('Foursquare', 'imate') => 'social-media-elements-foursquare,Foursquare',
                        esc_html__('GitHub', 'imate') => 'fa fa-github,GitHub',
                        esc_html__('Google', 'imate') => 'social-media-elements-google-plus,Google',
                        esc_html__('Instagram', 'imate') => 'social-media-elements-instagram,Instagram',
                        esc_html__('LinkedIn', 'imate') => 'social-media-elements-linkedin,LinkedIn',
                        esc_html__('Windows', 'imate') => 'fa fa-windows,Windows',
                        esc_html__('Odnoklassniki', 'imate') => 'fa fa-odnoklassniki,Odnoklassniki',
                        esc_html__('OpenID', 'imate') => 'fa fa-openid,OpenID',
                        esc_html__('Pinterest', 'imate') => 'social-media-elements-pinterest,Pinterest',
                        esc_html__('Reddit', 'imate') => 'fa fa-reddit,Reddit',
                        esc_html__('SoundCloud', 'imate') => 'social-media-elements-soundcloud,SoundCloud',
                        esc_html__('Tumblr', 'imate') => 'social-media-elements-tumblr,Tumblr',
                        esc_html__('Twitter', 'imate') => 'social-media-elements-twitter,Twitter',
                        esc_html__('Vimeo', 'imate') => 'social-media-elements-vimeo,Vimeo',
                        esc_html__('VK', 'imate') => 'social-media-elements-vk,VK',
                        esc_html__('Yahoo', 'imate') => 'social-media-elements-yahoo,Yahoo',
                        esc_html__('Youtube', 'imate') => 'social-media-elements-youtube,Youtube',
                    ),
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Social link 5", "imate"),
                    "edit_field_class" => "vc_col-xs-6",
                    "param_name" => "social_link_5",
                ),
            )
        ) );
    }
     
     
    // Element HTML
    public function pt_team_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'carousel' => 'on',
                    'speed' => '500',
                    'autoplay' => 'on',
                    'autoplay_speed' => '3000',
                    'pauseohover' => 'on',
                    'arrows' => 'on',
                    'dots' => 'on',
                    'dots_color' => '',
                    'animation' => '',
                    'desktop_cols' => '3',
                    'tablet_cols' => '2',
                    'mobile_cols' => '1',
                ), 
                $atts
            )
        );

        $items_class = $id = uniqid('team-items-');

        if(!empty($animation)) {
            $items_class .= ' '.$this->getCSSAnimation($animation);
        }

        $html = $area_css = "";

        if($carousel == 'on') {
            if($autoplay == 'on') {
                $autoplay = 'true';
            } else {
                $autoplay = 'false';
            }

            if($dots == 'on') {
                $dots = 'true';
                $items_class .= ' with-dots';
            } else {
                $dots = 'false';
            }

            if($arrows == 'on') {
                $arrows = 'true';
            } else {
                $arrows = 'false';
            }

            if($pauseohover == 'on') {
                $pauseohover = 'true';
            } else {
                $pauseohover = 'false';
            }

            wp_enqueue_style( 'owl-carousel-css', get_template_directory_uri() . '/css/owl.carousel.css');
            wp_enqueue_script( 'owl-carousel-js', get_template_directory_uri() . '/js/owl.carousel.min.js', array('jquery') );
            wp_enqueue_script( 'imate-script', get_template_directory_uri() . '/js/script.js' );

            wp_add_inline_script('imate-script', "jQuery(document).ready(function(jQuery) {
                jQuery('.".esc_attr($id)."').each(function(){
                    var head_slider = jQuery(this);
                    if(jQuery(this).find('.team-item').length > 1){
                        head_slider.addClass('owl-carousel').owlCarousel({
                            loop:true,
                            items:1,
                            nav: ".esc_js($arrows).",
                            dots: ".esc_js($dots).",
                            autoplay: ".esc_js($autoplay).",
                            autoplayTimeout: ".esc_js($autoplay_speed).",
                            autoplayHoverPause: ".esc_js($pauseohover).",
                            smartSpeed: ".esc_js($speed).",
                            navText: false,
                            navClass: ['owl-prev material-design-icon-keyboard-left-arrow-button','owl-next material-design-icon-keyboard-right-arrow-button'],
                            margin: 30,
                            responsive:{
                                0:{
                                    nav: false,
                                },
                                480:{
                                    
                                },
                                768:{
                                    items: ".esc_js($mobile_cols).",
                                },
                                980:{
                                    items: ".esc_js($tablet_cols).",
                                },
                                1200:{
                                    items: ".esc_js($desktop_cols).",
                                },
                            },
                        });
                    }
                });
            });");
        }

        if(!empty($content)) {
            $content = str_replace('[pt_team_item', '[pt_team_item carousel="'.esc_attr($carousel).'" desktop_cols="'.esc_attr($desktop_cols).'" tablet_cols="'.esc_attr($tablet_cols).'" mobile_cols="'.esc_attr($mobile_cols).'"', $content);
        }

        ob_start();
        ?>

        <div class="team-carousel-area<?php echo esc_attr($area_css) ?>">
            <div class="team-carousel row <?php echo esc_attr($items_class) ?>">
                <?php echo do_shortcode($content) ?>
            </div>
        </div>

        <?php
        return ob_get_clean();
         
    }

    // Element HTML
    public function pt_team_item_html( $atts ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'avatar' => '',
                    'name' => '',
                    'post' => '',
                    'desc' => '',
                    'social_icon_1' => '',
                    'social_link_1' => '',
                    'social_icon_2' => '',
                    'social_link_2' => '',
                    'social_icon_3' => '',
                    'social_link_3' => '',
                    'social_icon_4' => '',
                    'social_link_4' => '',
                    'social_icon_5' => '',
                    'social_link_5' => '',
                    'carousel' => 'on',
                    'desktop_cols' => '3',
                    'tablet_cols' => '2',
                    'mobile_cols' => '1',
                ), 
                $atts
            )
        );
        
        // Fill $html var with data

        $html = $avatar_url = $social_buttons_html = $item_css = "";

        if((!empty($social_icon_1) && !empty($social_link_1)) || (!empty($social_icon_2) && !empty($social_link_2)) || (!empty($social_icon_3) && !empty($social_link_3)) || (!empty($social_icon_4) && !empty($social_link_4)) || (!empty($social_icon_5) && !empty($social_link_5))) {
            $social_buttons_html = '<div class="social-buttons">';
                if(!empty($social_icon_1) && !empty($social_link_1)) {
                    $array = explode(',', $social_icon_1);
                    $social_buttons_html .= '<a href="'.esc_url($social_link_1).'" target="_blank"><i class="'.esc_attr($array[0]).'"></i><span>'.esc_attr($array[1]).'</span></a>';
                }
                if(!empty($social_icon_2) && !empty($social_link_2)) {
                    $array = explode(',', $social_icon_2);
                    $social_buttons_html .= '<a href="'.esc_url($social_link_2).'" target="_blank"><i class="'.esc_attr($array[0]).'"></i><span>'.esc_attr($array[1]).'</span></a>';
                }
                if(!empty($social_icon_3) && !empty($social_link_3)) {
                    $array = explode(',', $social_icon_3);
                    $social_buttons_html .= '<a href="'.esc_url($social_link_3).'" target="_blank"><i class="'.esc_attr($array[0]).'"></i><span>'.esc_attr($array[1]).'</span></a>';
                }
                if(!empty($social_icon_3) && !empty($social_link_4)) {
                    $array = explode(',', $social_icon_4);
                    $social_buttons_html .= '<a href="'.esc_url($social_link_4).'" target="_blank"><i class="'.esc_attr($array[0]).'"></i><span>'.esc_attr($array[1]).'</span></a>';
                }
                if(!empty($social_icon_3) && !empty($social_link_5)) {
                    $array = explode(',', $social_icon_5);
                    $social_buttons_html .= '<a href="'.esc_url($social_link_5).'" target="_blank"><i class="'.esc_attr($array[0]).'"></i><span>'.esc_attr($array[1]).'</span></a>';
                }
            $social_buttons_html .= '</div>';
        }

        if(isset(wp_get_attachment_image_src($avatar, 'large')[0])) {
            $avatar_url = wp_get_attachment_image_src($avatar, 'large')[0];
        }

        if($carousel == 'off') {
            $item_css = ' col-xs-12 col-sm-'.(12/$mobile_cols).' col-md-'.(12/$tablet_cols).' col-lg-'.(12/$desktop_cols);
        }

        ob_start();
        ?>

        <div class="team-item<?php echo esc_attr($item_css) ?>">
            <div class="image-area">
                <?php if(!empty($avatar_url)) { ?>
                    <div class="image" style="background-image: url(<?php echo esc_url($avatar_url) ?>);"></div>
                <?php } ?>
                <div class="content">
                    <?php if(!empty($social_buttons_html)) { ?>
                        <?php echo wp_kses_post($social_buttons_html) ?>
                    <?php } ?>
                </div>
            </div>
            <div class="bottom">
                <?php if(!empty($name)) { ?>
                    <h6 class="h"><?php echo wp_kses_post($name) ?></h6>
                <?php } if(!empty($post)) { ?>
                    <div class="post"><?php echo wp_kses_post($post) ?></div>
                <?php } ?>
            </div>
        </div>
        
        <?php
        return ob_get_clean();
         
    }
     
} // End Element Class
 
 
// Element Class Init
new PT_Team();    
if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
    class WPBakeryShortCode_PT_Team extends WPBakeryShortCodesContainer {
    }
}
if ( class_exists( 'WPBakeryShortCode' ) ) {
    class WPBakeryShortCode_PT_Team_Item extends WPBakeryShortCode {
    }
}

