<?php

// Element Description: PT Testimonials

class PT_Testimonials extends WPBakeryShortCode {
     
    // Element Init
    function __construct() {
        add_action( 'init', array( $this, 'pt_testimonials_mapping' ) );
        add_shortcode( 'pt_testimonials', array( $this, 'pt_testimonials_html' ) );
        add_shortcode( 'pt_testimonials_item', array( $this, 'pt_testimonials_item_html' ) );
    }
     
    // Element Mapping
    public function pt_testimonials_mapping() {
         
        // Stop all if VC is not enabled
        if ( !defined( 'WPB_VC_VERSION' ) ) {
            return;
        }
         
        // Map the block with vc_map()
        vc_map( array(
            "name" => esc_html__("Testimonials", "imate"),
            "base" => "pt_testimonials",
            "as_parent" => array('only' => 'pt_testimonials_item'),
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-testimonials",
            "is_container" => true,
            "category" => esc_html__("By PT", "imate"),
            "params" => array(
                array(
                    "type"        => "number",
                    "heading"     => esc_html__( "Transition speed", "imate" ),
                    "param_name"  => "speed",
                    "value"       => "300",
                    "min"         => "100",
                    "max"         => "10000",
                    "step"        => "100",
                    "suffix"      => "ms",
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Autoplay Slides", "imate" ),
                    "param_name"  => "autoplay",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "label" => esc_html__( "Enable Autoplay", "imate" ),
                            "on"    => "Yes",
                            "off"   => "No",
                        ),
                    ),
                    "default_set" => true,
                ),
                array(
                    "type"        => "switch",
                    "heading"     => esc_html__( "Pagination dots", "imate" ),
                    "param_name"  => "dots",
                    "value"       => "on",
                    "options"     => array(
                        "on" => array(
                            "on"    => "Yes",
                            "off"   => "No",
                        ),
                    ),
                    "default_set" => true,
                ),
                array(
                    "type"       => "number",
                    "heading"    => esc_html__( "Autoplay Speed", "imate" ),
                    "param_name" => "autoplay_speed",
                    "value"      => "5000",
                    "min"        => "100",
                    "max"        => "10000",
                    "step"       => "10",
                    "suffix"     => "ms",
                ),
                array(
                    "type"       => "switch",
                    "heading"    => esc_html__( "Pause on hover", "imate" ),
                    "param_name" => "pauseohover",
                    "value"      => "on",
                    "options"    => array(
                        "on" => array(
                            "label" => esc_html__( "Pause the slider on hover", "imate" ),
                            "on"    => "Yes",
                            "off"   => "No",
                        ),
                    ),
                    "dependency" => Array("element" => "autoplay", "value" => "on" ),
                ),
                array(
                    "type" => "animation_style",
                    "heading" => esc_html__( "Animation In", "imate" ),
                    "param_name" => "animation",
                ),
            ),
            "js_view" => 'VcColumnView'
        ) );
        vc_map( array(
            "name" => esc_html__("Testimonials item", "imate"),
            "base" => "pt_testimonials_item",
            "content_element" => true,
            "show_settings_on_create" => true,
            "icon" => "shortcode-icon-testimonials",
            "as_child" => array('only' => 'pt_testimonials'),
            "params" => array(
                array(
                    "type" => "attach_image",
                    "heading" => esc_html__("Avatar", "imate"),
                    "param_name" => "avatar",
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Name", "imate"),
                    "param_name" => "name",
                    "admin_label" => true,
                ),
                array(
                    "type" => "textfield",
                    "heading" => esc_html__("Post", "imate"),
                    "param_name" => "post",
                ),
                array(
                    "type" => "textarea",
                    "heading" => esc_html__("Text", "imate"),
                    "param_name" => "text",
                ),
            )
        ) );
    }
     
     
    // Element HTML
    public function pt_testimonials_html( $atts, $content = null ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'uniq_id' => uniqid(),
                    'speed' => '500',
                    'dots' => 'on',
                    'arrows' => 'on',
                    'autoplay' => 'on',
                    'autoplay_speed' => '3000',
                    'pauseohover' => 'on',
                    'animation' => ''
                ), 
                $atts
            )
        );

        $item_class = $id = uniqid('testimonials-');

        if(!empty($animation)) {
            $item_class .= ' '.$this->getCSSAnimation($animation);
        }

        $html = "";

        // Fill $html var with data
        $custom_css = "";

        if(!empty($custom_css)) {
            wp_enqueue_style('imate-custom-style', get_template_directory_uri() . '/css/custom_script.css');
            wp_add_inline_style( 'imate-custom-style', $custom_css );
        }

        
        if($autoplay == 'on') {
            $autoplay = 'true';
        } else {
            $autoplay = 'false';
        }
        if($pauseohover == 'on') {
            $pauseohover = 'true';
        } else {
            $pauseohover = 'false';
        }
        if($dots == 'on') {
            $dots = 'true';
            $item_class .= ' with-pagination-dots';
        } else {
            $dots = 'false';
        }

        wp_enqueue_style( 'owl-carousel-css', get_template_directory_uri() . '/css/owl.carousel.css');
        wp_enqueue_script( 'owl-carousel-js', get_template_directory_uri() . '/js/owl.carousel.min.js', array('jquery') );
        wp_enqueue_script( 'imate-script', get_template_directory_uri() . '/js/script.js' );

        wp_add_inline_script('imate-script', "jQuery(document).ready(function(jQuery) {
            jQuery('.".esc_attr($id)."').each(function(){
                var head_slider = jQuery(this);
                if(jQuery(this).find('.testimonial-item').length > 1){
                    head_slider.addClass('owl-carousel').owlCarousel({
                        loop:true,
                        items:1,
                        center: true,
                        nav: false,
                        dots: ".esc_js($dots).",
                        autoplay: ".esc_js($autoplay).",
                        autoplayTimeout: ".esc_js($autoplay_speed).",
                        autoplayHoverPause: ".esc_js($pauseohover).",
                        smartSpeed: ".esc_js($speed).",
                        autoHeight: true,
                        autoWidth: true,
                        navClass: ['owl-prev material-design-icon-keyboard-left-arrow-button','owl-next material-design-icon-keyboard-right-arrow-button'],
                        autoHeight: true,
                        navText: false,
                        margin: 30,
                    });
                }
            });
        });");

        ob_start();
        ?>
        <div class="testimonials <?php echo esc_attr($item_class) ?>">
            <?php echo do_shortcode($content) ?>
        </div>
         
        <?php
        return ob_get_clean();
         
    }

    // Element HTML
    public function pt_testimonials_item_html( $atts ) {
         
        // Params extraction
        extract(
            shortcode_atts(
                array(
                    'avatar' => '',
                    'name' => '',
                    'post' => '',
                    'text' => '',
                ), 
                $atts
            )
        );

        $avatar_attr = "";

        if(isset(wp_get_attachment_image_src($avatar, 'full')[0])) {
            $avatar_attr = 'background-image: url('.esc_url(wp_get_attachment_image_src($avatar, 'full')[0]).')';
        }

        ob_start();
        ?>

        <div class="testimonial-item">
            <?php if(!empty($text)) { ?>
                <div class="quote"><?php echo wp_kses_post($text) ?></div>
            <?php } if(!empty($avatar_attr) || !empty($name) || !empty($post)) { ?>
                <div class="bottom">
                    <?php if(!empty($avatar_attr)) { ?>
                        <div class="avatar" style="<?php echo esc_attr($avatar_attr) ?>"></div>
                    <?php } if(!empty($name) || !empty($post)) { ?>
                        <div class="label">
                            <div class="cell">
                                <?php if(!empty($name)) { ?>
                                    <div class="name"><?php echo wp_kses_post($name) ?></div>
                                <?php } if(!empty($post)) { ?>
                                    <div class="post"><?php echo wp_kses_post($post) ?></div>
                                <?php } ?>
                            </div>
                        </div>
                    <?php } ?>
                </div>
            <?php } ?>
        </div>
        
        <?php
        return ob_get_clean();
         
    }
     
} // End Element Class
 
 
// Element Class Init
new PT_Testimonials();    
if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
    class WPBakeryShortCode_PT_Testimonials extends WPBakeryShortCodesContainer {
    }
}
if ( class_exists( 'WPBakeryShortCode' ) ) {
    class WPBakeryShortCode_PT_Testimonials_Item extends WPBakeryShortCode {
    }
}

